// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_LOCAL_H__
#define __INTERNAL_TERRITORY_NAMES_LOCAL_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***
static const char *TERRITORY_FULL_NAME_LOCAL[] = {
        "Sancta Sedes|Holy See",
        "Monaco",
        "Gibraltar",
        "Tokelau",
        "Kepulauan Cocos|Cocos Islands|Keeling Islands",
        "Saint-Barthélemy",
        "Naoero",
        "Tuvalu",
        "澳门|Macao|澳門|澳门特别行政区",
        "Sint Maarten|Saint-Martin",
        "Sint Maarten|Saint-Martin",
        "Norfolk Island|Philip Island",
        "Pitkern Ailen|Pitkern",
        "Bouvetøya|Bouvet-øya",
        "Bermuda",
        "British Indian Ocean Territory",
        "San Marino",
        "Guernsey",
        "Anguilla",
        "Montserrat",
        "Bailliage dé Jèrri",
        "Christmas Island",
        "Wallis-et-Futuna|Uvea mo Futuna",
        "Virgin Islands",
        "Liechtenstein",
        "Aruba",
        "Aolepān Aorōkin M̧ajeļ|Marshall Islands|The Marshall Islands",
        "Amerika Sāmoa|American Samoa",
        "Kūki 'Āirani|Cook Islands",
        "Saint-Pierre-et-Miquelon",
        "Niuē",
        "Saint Kitts and Nevis",
        "Cayman islands",
        "Boneiru|Sint Eustatius|Saba|Statia",
        "ދިވެހިރާއްޖޭގެ ޖުމްހޫރިއްޔާ|Dhivehi Raa'jeyge Jumhooriyya",
        "Saint Helena|Saint Helena, Ascension and Tristan da Cunha",
        "Malta",
        "La Grenade",
        "United States Virgin Islands|American Virgin Islands",
        "Mayotte|Maore",
        "Svalbard og Jan Mayen|Шпицберген и Ян-Майен",
        "Saint Vincent and the Grenadines|Saint Vincent",
        "Heard Island|McDonald Islands",
        "Barbados",
        "Antigua and Barbuda",
        "Curaçao|Kòrsou",
        "Seychelles|Sesel",
        "Belau|Pelew",
        "Islas Mariånas|llól Marianas",
        "Principat d'Andorra|Andorra",
        "Guam|Guåhån",
        "Ellan Vannin|Mann|Mannin",
        "Sainte-Lucie",
        "Micronesia",
        "新加坡|Singapura|சிங்கப்பூர்",
        "Tonga",
        "Dominique|Wai‘tu kubuli",
        "البحرين‎|al-Baḥrayn",
        "Kiribati",
        "Turks and Caicos Islands",
        "São Tomé e Príncipe|São Tomé|Príncipe",
        "香港|Hong Kong|香港特别行政区",
        "Martinique",
        "Føroyar|Færøerne",
        "Gwadloup|Guadeloupe",
        "جزر القمر‎‎|Comores  |Komori",
        "Maurice|Moris",
        "Réunion|La Réunion",
        "Lëtzebuerg|Luxemburg",
        "Sāmoa",
        "SGSSI",
        "Polynésie française|Pōrīnetia Farāni",
        "Cabo Verde",
        "Trinidad and Tobago",
        "بروني دارالسلام|Brunei Darussalam",
        "Terres australes et antarctiques françaises|TAAF",
        "Puerto Rico",
        "Κύπρος|Kıbrıs",
        "لبنان‎‎|Libnān",
        "Jamaica",
        "The Gambia|Gambia",
        "قطر‎‎|Qaṭar",
        "Islas Malvinas|Falkland Islands",
        "Vanuatu",
        "Црна Гора|Crna Gora",
        "Bahamas",
        "Timór Lorosa'e|Timór-Leste",
        "Umbuso weSwatini|kaNgwane|Eswatini",
        "دولة الكويت|Kuwait",
        "Viti|फ़िजी",
        "Nouvelle-Calédonie",
        "Slovenija",
        "יִשְׂרָאֵל|إِسْرَائِيل‎‎|Israel",
        "دولة فلسطين|מדינת פלסטין|الأراضي الفلسطينية",
        "El Salvador",
        "Belize",
        "جيبوتي‎‎|Jabuuti|Gabuuti",
        "Македонија|Macedonia",
        "Rwanda",
        "Haïti|Ayiti",
        "Uburundi|Burundi",
        "Guinea Ecuatorial|Guinée équatoriale|Guiné Equatorial",
        "Shqipëri|Shqipëria|Shqipni|Shqypni",
        "Solomon Islands",
        "Հայաստան|Hayastan",
        "'Muso oa Lesotho",
        "België|Belgique|Belgien",
        "Moldova",
        "Guiné-Bissau",
        "中華民國|中华民国",
        "འབྲུག་ཡུལ་|འབྲུག་རྒྱལ་ཁབ་",
        "Schweiz|suisse|Svizzera  ",
        "Nederland",
        "Danmark",
        "Eesti",
        "República Dominicana",
        "Slovensko",
        "Costa Rica",
        "Bosna i Hercegovina|Босна и Херцеговина",
        "Hrvatska",
        "République togolaise|Togo",
        "Latvija",
        "Lietuva",
        "ශ්‍රී ලංකා|இலங்கை|Sri Lanka ",
        "საქართველო|Грузия|Sakartvelo",
        "Éire|Airlann",
        "Sierra Leone",
        "Panamá",
        "Česká republika|Česko",
        "Guyane française|Guyane|Guiana ",
        "الإمارات العربية المتحدة|Emirates|UAE",
        "Österreich",
        "Azərbaycan",
        "Србија|Srbija",
        "الأردن‎‎|Jordan",
        "Portugal",
        "Magyarország",
        "대한민국|South Korea",
        "Ísland",
        "Guatemala",
        "Cuba",
        "България",
        "Liberia",
        "Honduras",
        "Bénin",
        "ኤርትሪያ|إريتريا|Eritrea",
        "Malaŵi",
        "조선 민주주의 인민 공화국",
        "Nicaragua",
        "Ελλάδα|Hellas",
        "Тоҷикистон",
        "বাংলাদেশ",
        "नेपाल|Nepāl",
        "تونس‎‎|Tunisie|ⵜⵓⵏⴻⵙ",
        "Suriname|Surinam",
        "Uruguay",
        "កម្ពុជា",
        "سوريا‎‎|Syria|سورية",
        "Sénégal",
        "Кыргызстан|Киргизия",
        "Белару́сь|Belarus|بيَلارُث|Беларусь",
        "Guyana",
        "ລາວ|Lao",
        "România",
        "Ghana",
        "Uganda",
        "United Kingdom",
        "Guinée",
        "Ecuador",
        "الصحراء الغربية|Taneẓroft Tutrimt",
        "Gabon",
        "Aotearoa",
        "Burkina Faso",
        "Pilipinas",
        "Italia",
        "عمان‎‎|Oman",
        "Polska",
        "Côte d'Ivoire",
        "Norge|Noreg",
        "Malaysia|马来西亚",
        "Việt Nam",
        "Suomi",
        "Congo",
        "Deutschland",
        "日本|Nippon|Nihon|日本国",
        "Zimbabwe",
        "Paraguái|Paraguay",
        "العراق‎‎|Irāq",
        "المغرب‎‎|Morocco|ⵍⵎⴰⵖⵔⵉⴱ",
        "Oʻzbekiston",
        "Sverige",
        "Papua Niugini|Papua Niu Gini",
        "Cameroun",
        "Түркменистан|Türkmenistan|تۆركمنيستآن",
        "España",
        "ประเทศไทย|Prathet Thai",
        "اليَمَن‎‎|Yemen",
        "France",
        "Åland|Ahvenanmaa",
        "Kenya",
        "Botswana",
        "Madagasikara|Madagascar",
        "Україна",
        "South Sudan|جنوب السودان",
        "Ködörösêse tî Bêafrîka|Centrafricaine",
        "الصومال‎‎|Soomaaliya",
        "افغانستان|Afġānistān",
        "ပြည်ထောင်စု သမ္မတ မြန်မာနိုင်ငံတော်‌|Myanmar",
        "Zambia",
        "Chile",
        "Türkiye",
        "پاکستان|Pakistan",
        "Moçambique",
        "Namibië|Namibia",
        "Venezuela",
        "Nijeriya|Naìjíríyà|Nàìjíríà",
        "Tanzania",
        "مِصر‎‎|Egypt|مَصر‎‎",
        "موريتانيا|Mauritanie|Muritanya|Gànnaar",
        "Buliwya|Wuliwya|Bolivia",
        "Ethiopia|ኢትዮጵያ",
        "Colombia",
        "Zuid-Afrika|Suid-Afrika|Afrika Borwa",
        "Mali",
        "Angola",
        "Niger",
        "تشاد‎‎|Tchad|Chad",
        "Perú|Piruw",
        "Монгол Улс|ᠮᠤᠩᠭᠤᠯ ᠤᠯᠤᠰ",
        "ایران|Iran|Persia ",
        "ليبيا‎‎|Libya|دولة ليبيا",
        "السودان‎‎|Sudan",
        "Indonesia",
        "Mexico City",
        "Tlaxcala",
        "Morelos",
        "Aguascalientes",
        "Colima",
        "Querétaro|Querétaro de Arteaga",
        "Hidalgo",
        "México",
        "Tabasco",
        "Nayarit",
        "Guanajuato",
        "Puebla",
        "Yucatán",
        "Quintana Roo",
        "Sinaloa",
        "Campeche",
        "Michoacán|Michoacán de Ocampo",
        "San Luis Potosí",
        "Guerrero",
        "Nuevo León",
        "Baja California Sur",
        "Veracruz",
        "Chiapas",
        "Baja California",
        "Zacatecas",
        "Jalisco",
        "Tamaulipas",
        "Oaxaca",
        "Durango",
        "Coahuila|Coahuila de Zaragoza",
        "Sonora",
        "Chihuahua",
        "Grønland|Kalaallit Nunaat",
        "السعودية|Saudi Arabia|المملكة العربية السعودية",
        "Kongo",
        "الجزائر‎‎|Algérie|ⴷⵣⴰⵢⴻⵔ",
        "Қазақстан|Qazaqstan|Kazakhstan",
        "Argentina|Argentine",
        "दमण आणि दीव|દમણ અને દીવ|Damão e Diu",
        "दादरा और नगर हवेली|દાદરા અને નગર હવેલી|Dadra and Nagar Haveli",
        "चंडीगढ़|Chandigarh|ਚੰਡੀਗੜ੍ਹ",
        "अण्डमान और निकोबार|Andaman and Nicobar|আন্দামান ও নিকোবর",
        "ലക്ഷദ്വീപ്|Lakshadweep|लक्षद्वीप",
        "दिल्ली|ਦਿੱਲੀ '|Delhi",
        "Megahalaya|मेघालय",
        "Nagaland|नगालैंड",
        "মণিপুর",
        "ত্রিপুরা",
        "मिजोरम|Mizoram",
        "सिक्किम",
        "ਪੰਜਾਬ|पंजाब|Punjab",
        "हरियाणा|ਹਰਿਆਣਾ|Haryana",
        "Arunachal Pradesh|अरुणाचल प्रदेश",
        "অসম",
        "बिहार|بہار",
        "उत्तराखण्ड",
        "गोंय",
        "കേരളം|Kerala|केरल",
        "தமிழ்நாடு|तमिलनाडु",
        "हिमाचल प्रदेश|Himachal Pradesh",
        "جموں و کشمی|जम्मू और कश्मीर|ਜੰਮੂ ਅਤੇ ਕਸ਼ਮੀਰ",
        "छत्तीसगढ़",
        "झारखण्ड|ঝাড়খণ্ড|Jharkhand",
        "ಕರ್ನಾಟಕ|कर्नाटक|Karnataka",
        "राजस्थान",
        "ଓଡ଼ିଶା|Odisha",
        "ગુજરાત|Gujarat|गुजरात",
        "পশ্চিমবঙ্গ|West Bengal",
        "मध्य प्रदेश",
        "తెలంగాణ|تلنگانہ|तेलंगाना",
        "ఆంధ్ర ప్రదేశ్|आंध्र प्रदेश",
        "महाराष्ट्र",
        "उत्तर प्रदेश|Uttar Pradesh|اتر پردیش",
        "പുതുച്ചേരി|పుదుచ్చేరి|पुडुचेरी|Puducherry",
        "New South Wales",
        "Australian Capital Territory|Capital Territory",
        "Jervis Bay Territory|Jervis Bay",
        "Northern Territory",
        "South Australia",
        "Tasmania",
        "Victoria",
        "Western Australia",
        "Queensland",
        "Distrito Federal",
        "Sergipe",
        "Alagoas",
        "Rio de Janeiro",
        "Espirito Santo",
        "Rio Grande do Norte",
        "Paraíba",
        "Santa Catarina",
        "Pernambuco",
        "Amapá",
        "Ceará",
        "Acre",
        "Paraná",
        "Roraima",
        "Rondônia",
        "São Paulo",
        "Piauí",
        "Tocantins",
        "Rio Grande do Sul",
        "Maranhão",
        "Goiás",
        "Mato Grosso do Sul",
        "Bahia",
        "Minas Gerais",
        "Mato Grosso",
        "Pará",
        "Amazonas",
        "District of Columbia",
        "Rhode Island",
        "Delaware",
        "Connecticut",
        "New Jersey",
        "New Hampshire",
        "Vermont",
        "Massachusetts",
        "Hawaii",
        "Maryland",
        "West Virginia",
        "South Carolina",
        "Maine",
        "Indiana",
        "Kentucky",
        "Tennessee",
        "Virginia",
        "Ohio",
        "Pennsylvania",
        "Mississippi",
        "Louisiana",
        "Alabama",
        "Arkansas",
        "North Carolina",
        "New York",
        "Iowa",
        "Illinois",
        "Georgia",
        "Wisconsin",
        "Florida",
        "Missouri",
        "Oklahoma",
        "North Dakota",
        "Washington",
        "South Dakota",
        "Nebraska",
        "Kansas",
        "Idaho",
        "Utah",
        "Minnesota",
        "Michigan",
        "Wyoming",
        "Oregon",
        "Colorado",
        "Nevada",
        "Arizona",
        "New Mexico",
        "Montana",
        "California",
        "Texas",
        "Alaska",
        "Colombie-Britannique|British Columbia",
        "Alberta",
        "Ontario",
        "Québec|Quebec",
        "Saskatchewan",
        "Manitoba",
        "Newfoundland and Labrador|Terre-Neuve-et-Labrador",
        "New Brunswick|Nouveau-Brunswick",
        "Nova Scotia|Nouvelle-Écosse",
        "Prince Edward Island|Île-du-Prince-Édouard",
        "Yukon",
        "Northwest Territories|Territoires du Nord-Ouest",
        "Nunavut",
        "इंडिया|ভারত|India",
        "Australia",
        "Brasil",
        "America|United States",
        "México|United Mexican States|Estados Unidos Mexicanos",
        "Москва́|Москва ",
        "Санкт-Петербург ",
        "Калининградская область",
        "Респу́блика Ингуше́тия|Гӏалгӏай Мохк",
        "Респу́блика Адыге́я|дыгэ Республик",
        "Республика Северная Осетия - Алания|Республикӕ Цӕгат Ирыстон",
        "Кабардино-Балкарская Республика|Къэбэрдей-Балъкъэр Республикэ |Къабарты-Малкъар Республика",
        "Карачаево-Черкесская Республика|Къарачай-Черкес Республика|Къэрэшей-Шэрджэс Республикэ",
        "Чеченская Республика|Нохчийн Республика|Чечня́|Нохчийчоь",
        "Чува́шия",
        "Ивановская область",
        "Липецкая область",
        "Орловская область",
        "Ту́льская о́бласть",
        "Белгоро́дская о́бласть",
        "Влади́мирская о́бласть",
        "Курская область",
        "Калужская область",
        "Тамбовская область",
        "Брянская область",
        "Ярославская область",
        "Рязанская область",
        "Астраханская область",
        "Подмоско́вье|Московская область",
        "Смоле́нская о́бласть",
        "Республика Дагестан ",
        "Воронежская область",
        "Новгородская область",
        "Псковская область",
        "Костромская область",
        "Ставропольский край",
        "Краснодарский край ",
        "Хальмг|Kalmykiya|Респу́блика Калмы́кия",
        "Тверская область",
        "Ленингра́дская о́бласть",
        "Росто́вская о́бласть",
        "Волгогра́дская о́бласть",
        "Вологодская область",
        "Му́рманская о́бласть",
        "Респу́блика Каре́лия",
        "Не́нецкий автоно́мный о́круг|Ненёцие автономной ӈокрук",
        "Респу́блика Ко́ми|Коми Республика",
        "Арха́нгельская о́бласть",
        "Респу́блика Мордо́вия|Мордовия Республикась",
        "Нижегоро́дская о́бласть",
        "Пе́нзенская о́бласть",
        "Ки́ровская о́бласть",
        "Республика Марий Эл|Марий Эл Республик |Мары Эл Республик",
        "Оренбу́ргская о́бласть",
        "Ульяновская область",
        "Пермский край",
        "Республика Башкортостан|Башҡортостан Республикаһы ",
        "Удмуртская Республика|Удмурт Элькун",
        "Республика Татарстан|Татарстан Республикасы",
        "Самарская область",
        "Саратовская область",
        "Ямало-Ненецкий автономный округ|Ямалы-Ненёцие автономной ӈокрук",
        "Ханты-Мансийский автономный округ - Югра|Ханты-Мансийский",
        "Свердловская область ",
        "Тюменская область",
        "Курганская область ",
        "Челябинская область ",
        "Республика Бурятия|Буряад Улас",
        "Забайкальский край",
        "Иркутская область",
        "Новосибирская область",
        "Томская область",
        "Омская область",
        "Республика Хакасия|Хакас Республиказы",
        "Кемеровская область",
        "Республика Алтай|Алтай Республика",
        "Алтайский край ",
        "Республика Тыва|Тыва Республика",
        "Красноярский край",
        "Магаданская область",
        "Чукотский автономный округ|Чукоткакэн автономныкэн округ",
        "Камчатский край ",
        "Сахалинская область ",
        "Приморский край ",
        "Еврейская автономная область",
        "Хабаровский край",
        "Амурская область",
        "Республика Саха|Якутия|Саха Өрөспүүбүлүкэтэ",
        "Canada",
        "Росси́я",
        "上海市",
        "天津市",
        "北京市",
        "海南省",
        "宁夏|宁夏回族自治区",
        "重庆市",
        "浙江省",
        "江苏省",
        "福建省",
        "安徽省",
        "辽宁省",
        "山东省",
        "山西省",
        "江西省",
        "河南省",
        "贵州省",
        "广东省",
        "湖北省",
        "吉林省",
        "河北省",
        "陕西省",
        "内蒙古自治区",
        "黑龙江省",
        "湖南省",
        "广西壮族自治区",
        "四川省",
        "云南省",
        "བོད་|新疆维吾尔自治区|西藏",
        "甘肃省",
        "青海省",
        "西藏|བོད་|Tibet|西藏自治区",
        "中國|中华人民共和国",
        "United States Minor Outlying Islands|USMOI",
        "Île de Clipperton|Isla de la Pasión",
        "Antarctica",
        "Earth"
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_LOCAL_H__
