// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_CN_H__
#define __INTERNAL_TERRITORY_NAMES_CN_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_CN[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_CN // Chinese
        /*     VAT */ "梵蒂冈城|教廷",
        /*     MCO */ "摩纳哥",
        /*     GIB */ "直布罗陀",
        /*     TKL */ "托克劳",
        /*     CCK */ "科科斯群岛|基林群岛",
        /*     BLM */ "圣巴泰勒米",
        /*     NRU */ "瑙鲁",
        /*     TUV */ "图瓦卢",
        /*     MAC */ "澳门",
        /*     SXM */ "圣马丁",
        /*     MAF */ "圣马丁",
        /*     NFK */ "诺福克岛和菲利普岛|菲利普岛",
        /*     PCN */ "皮特凯恩群岛",
        /*     BVT */ "布韦岛",
        /*     BMU */ "百慕大",
        /*     IOT */ "英属印度洋领地",
        /*     SMR */ "圣马力诺",
        /*     GGY */ "根西岛",
        /*     AIA */ "安圭拉",
        /*     MSR */ "蒙特塞拉特",
        /*     JEY */ "泽西岛",
        /*     CXR */ "圣诞岛",
        /*     WLF */ "瓦利斯和富图纳",
        /*     VGB */ "英属维尔京群岛|维尔京群岛，英国",
        /*     LIE */ "列支敦士登",
        /*     ABW */ "阿鲁巴",
        /*     MHL */ "马绍尔群岛",
        /*     ASM */ "美属萨摩亚|萨摩亚，美国",
        /*     COK */ "库克岛",
        /*     SPM */ "圣皮埃尔和密克隆",
        /*     NIU */ "纽埃",
        /*     KNA */ "圣基茨和尼维斯|尼维斯",
        /*     CYM */ "开曼群岛",
        /*     BES */ "博内尔岛，圣尤斯图斯和萨巴|萨巴",
        /*     MDV */ "马尔代夫",
        /*     SHN */ "圣赫勒拿，阿森松和特里斯坦达库尼亚|阿森松|特里斯坦达库尼亚",
        /*     MLT */ "马耳他",
        /*     GRD */ "格林纳达",
        /*     VIR */ "美属维尔京群岛|美属维尔京群岛",
        /*     MYT */ "马约特",
        /*     SJM */ "斯瓦尔巴和杨梅",
        /*     VCT */ "圣文森特和格林纳丁斯|格林纳丁斯",
        /*     HMD */ "赫德岛和麦克唐纳群岛|麦克唐纳群岛",
        /*     BRB */ "巴巴多斯",
        /*     ATG */ "安提瓜和巴布达|巴布达",
        /*     CUW */ "库拉索",
        /*     SYC */ "塞舌尔",
        /*     PLW */ "帕劳",
        /*     MNP */ "北马里亚那群岛",
        /*     AND */ "安道尔",
        /*     GUM */ "关岛",
        /*     IMN */ "马恩岛",
        /*     LCA */ "圣卢西亚",
        /*     FSM */ "密克罗尼西亚|密克罗尼西亚联邦",
        /*     SGP */ "新加坡",
        /*     TON */ "汤加",
        /*     DMA */ "多米尼加",
        /*     BHR */ "巴林",
        /*     KIR */ "基里巴斯",
        /*     TCA */ "特克斯和凯科斯群岛|凯科斯群岛",
        /*     STP */ "圣多美和普林西比",
        /*     HKG */ "香港",
        /*     MTQ */ "马提尼克",
        /*     FRO */ "法罗群岛",
        /*     GLP */ "瓜德罗普",
        /*     COM */ "科摩罗",
        /*     MUS */ "毛里求斯",
        /*     REU */ "团圆",
        /*     LUX */ "卢森堡",
        /*     WSM */ "萨摩亚",
        /*     SGS */ "南乔治亚和南桑威奇群岛|南桑威奇群岛",
        /*     PYF */ "法属波利尼西亚",
        /*     CPV */ "佛得角",
        /*     TTO */ "特立尼达和多巴哥|多巴哥",
        /*     BRN */ "文莱",
        /*     ATF */ "法国南部和南极土地",
        /*     PRI */ "波多黎各",
        /*     CYP */ "塞浦路斯",
        /*     LBN */ "黎巴嫩",
        /*     JAM */ "牙买加",
        /*     GMB */ "冈比亚",
        /*     QAT */ "卡塔尔",
        /*     FLK */ "福克兰群岛",
        /*     VUT */ "瓦努阿图",
        /*     MNE */ "黑山",
        /*     BHS */ "巴哈马",
        /*     TLS */ "东帝汶",
        /*     SWZ */ "斯威士兰",
        /*     KWT */ "科威特",
        /*     FJI */ "斐济",
        /*     NCL */ "新喀里多尼亚",
        /*     SVN */ "斯洛文尼亚",
        /*     ISR */ "以色列",
        /*     PSE */ "巴勒斯坦领土",
        /*     SLV */ "萨尔瓦多",
        /*     BLZ */ "伯利兹",
        /*     DJI */ "吉布提",
        /*     MKD */ "马其顿",
        /*     RWA */ "卢旺达",
        /*     HTI */ "海地",
        /*     BDI */ "布隆迪",
        /*     GNQ */ "赤道几内亚",
        /*     ALB */ "阿尔巴尼亚",
        /*     SLB */ "所罗门群岛",
        /*     ARM */ "亚美尼亚",
        /*     LSO */ "莱索托",
        /*     BEL */ "比利时",
        /*     MDA */ "摩尔多瓦",
        /*     GNB */ "几内亚比绍",
        /*     TWN */ "台湾",
        /*     BTN */ "不丹",
        /*     CHE */ "瑞士",
        /*     NLD */ "荷兰",
        /*     DNK */ "丹麦",
        /*     EST */ "爱沙尼亚",
        /*     DOM */ "多明尼加共和国",
        /*     SVK */ "斯洛伐克",
        /*     CRI */ "哥斯达黎加",
        /*     BIH */ "波斯尼亚和黑塞哥维那",
        /*     HRV */ "克罗地亚",
        /*     TGO */ "多哥",
        /*     LVA */ "拉脱维亚",
        /*     LTU */ "立陶宛",
        /*     LKA */ "斯里兰卡",
        /*     GEO */ "格鲁吉亚",
        /*     IRL */ "爱尔兰",
        /*     SLE */ "塞拉利昂",
        /*     PAN */ "巴拿马",
        /*     CZE */ "捷克共和国",
        /*     GUF */ "法属圭亚那",
        /*     ARE */ "阿拉伯联合酋长国",
        /*     AUT */ "奥地利",
        /*     AZE */ "阿塞拜疆",
        /*     SRB */ "塞尔维亚",
        /*     JOR */ "约旦",
        /*     PRT */ "葡萄牙",
        /*     HUN */ "匈牙利",
        /*     KOR */ "韩国",
        /*     ISL */ "冰岛",
        /*     GTM */ "危地马拉",
        /*     CUB */ "古巴",
        /*     BGR */ "保加利亚",
        /*     LBR */ "利比里亚",
        /*     HND */ "洪都拉斯",
        /*     BEN */ "贝宁",
        /*     ERI */ "厄立特里亚",
        /*     MWI */ "马拉维",
        /*     PRK */ "北朝鲜",
        /*     NIC */ "尼加拉瓜",
        /*     GRC */ "希腊",
        /*     TJK */ "塔吉克斯坦",
        /*     BGD */ "孟加拉国",
        /*     NPL */ "尼泊尔",
        /*     TUN */ "突尼斯",
        /*     SUR */ "苏里南",
        /*     URY */ "乌拉圭",
        /*     KHM */ "柬埔寨",
        /*     SYR */ "叙利亚",
        /*     SEN */ "塞内加尔",
        /*     KGZ */ "吉尔吉斯斯坦",
        /*     BLR */ "白俄罗斯",
        /*     GUY */ "圭亚那",
        /*     LAO */ "老挝",
        /*     ROU */ "罗马尼亚",
        /*     GHA */ "加纳",
        /*     UGA */ "乌干达",
        /*     GBR */ "英国|苏格兰|英国|北爱尔兰|爱尔兰，北方",
        /*     GIN */ "几内亚",
        /*     ECU */ "厄瓜多尔",
        /*     ESH */ "西撒哈拉",
        /*     GAB */ "加蓬",
        /*     NZL */ "新西兰",
        /*     BFA */ "布基纳法索",
        /*     PHL */ "菲律宾",
        /*     ITA */ "意大利",
        /*     OMN */ "阿曼",
        /*     POL */ "波兰",
        /*     CIV */ "象牙海岸",
        /*     NOR */ "挪威",
        /*     MYS */ "马来西亚",
        /*     VNM */ "越南",
        /*     FIN */ "芬兰",
        /*     COG */ "刚果 - 布拉柴维尔",
        /*     DEU */ "德国",
        /*     JPN */ "日本",
        /*     ZWE */ "津巴布韦",
        /*     PRY */ "巴拉圭",
        /*     IRQ */ "伊拉克",
        /*     MAR */ "摩洛哥",
        /*     UZB */ "乌兹别克斯坦",
        /*     SWE */ "瑞典",
        /*     PNG */ "巴布亚新几内亚",
        /*     CMR */ "喀麦隆",
        /*     TKM */ "土库曼斯坦",
        /*     ESP */ "西班牙",
        /*     THA */ "泰国",
        /*     YEM */ "也门",
        /*     FRA */ "法国",
        /*     ALA */ "奥兰群岛",
        /*     KEN */ "肯尼亚",
        /*     BWA */ "博茨瓦纳",
        /*     MDG */ "马达加斯加",
        /*     UKR */ "乌克兰",
        /*     SSD */ "南苏丹",
        /*     CAF */ "中非共和国",
        /*     SOM */ "索马里",
        /*     AFG */ "阿富汗",
        /*     MMR */ "缅甸",
        /*     ZMB */ "赞比亚",
        /*     CHL */ "智利",
        /*     TUR */ "土耳其",
        /*     PAK */ "巴基斯坦",
        /*     MOZ */ "莫桑比克",
        /*     NAM */ "纳米比亚",
        /*     VEN */ "委内瑞拉",
        /*     NGA */ "尼日利亚",
        /*     TZA */ "坦桑尼亚",
        /*     EGY */ "埃及",
        /*     MRT */ "毛里塔尼亚",
        /*     BOL */ "玻利维亚",
        /*     ETH */ "埃塞俄比亚",
        /*     COL */ "哥伦比亚",
        /*     ZAF */ "南非",
        /*     MLI */ "马里",
        /*     AGO */ "安哥拉",
        /*     NER */ "尼日尔",
        /*     TCD */ "乍得",
        /*     PER */ "秘鲁",
        /*     MNG */ "蒙古",
        /*     IRN */ "伊朗",
        /*     LBY */ "利比亚",
        /*     SDN */ "苏丹",
        /*     IDN */ "印度尼西亚",
        /*     DIF */ "联邦区",
        /*     TLA */ "特拉斯卡拉",
        /*     MOR */ "莫雷洛斯",
        /*     AGU */ "阿瓜斯卡连特斯",
        /*   MX-CL */ "科利马",
        /*     QUE */ "克雷塔罗",
        /*     HID */ "伊达尔戈",
        /*   MX-MX */ "墨西哥州",
        /*     TAB */ "塔巴斯科",
        /*     NAY */ "纳亚里特",
        /*     GUA */ "瓜纳华托",
        /*     PUE */ "普埃布拉",
        /*     YUC */ "尤卡坦",
        /*     ROO */ "金塔纳罗奥",
        /*     SIN */ "锡那罗亚",
        /*     CAM */ "坎佩切",
        /*     MIC */ "米却肯",
        /*     SLP */ "圣路易斯波托西",
        /*     GRO */ "格雷罗",
        /*     NLE */ "新莱昂",
        /*     BCN */ "下加利福尼亚州",
        /*     VER */ "韦拉克鲁斯",
        /*     CHP */ "恰帕斯",
        /*     BCS */ "南下加利福尼亚州",
        /*     ZAC */ "萨卡特卡斯",
        /*     JAL */ "哈利斯科",
        /*     TAM */ "塔毛利帕斯州",
        /*     OAX */ "瓦哈卡",
        /*     DUR */ "杜兰戈",
        /*     COA */ "科阿韦拉",
        /*     SON */ "索诺拉",
        /*     CHH */ "奇瓦瓦",
        /*     GRL */ "格陵兰",
        /*     SAU */ "沙特阿拉伯",
        /*     COD */ "刚果 - 金沙萨",
        /*     DZA */ "阿尔及利亚",
        /*     KAZ */ "哈萨克斯坦",
        /*     ARG */ "阿根廷",
        /*   IN-DD */ "达曼-第乌",
        /*   IN-DN */ "达德拉-纳加尔哈维利",
        /*   IN-CH */ "昌迪加尔",
        /*   IN-AN */ "安达曼和尼科巴",
        /*   IN-LD */ "拉克沙群島",
        /*   IN-DL */ "德里",
        /*   IN-ML */ "梅加拉亚邦",
        /*   IN-NL */ "纳加兰",
        /*   IN-MN */ "曼尼普尔",
        /*   IN-TR */ "特里普拉邦",
        /*   IN-MZ */ "米佐拉姆邦",
        /*   IN-SK */ "锡金",
        /*   IN-PB */ "旁遮普",
        /*   IN-HR */ "哈里亚纳",
        /*   IN-AR */ "阿鲁纳恰尔邦",
        /*   IN-AS */ "阿萨姆邦",
        /*   IN-BR */ "比哈尔邦",
        /*   IN-UT */ "北阿坎德邦",
        /*   IN-GA */ "果阿",
        /*   IN-KL */ "喀拉拉",
        /*   IN-TN */ "泰米尔纳德邦",
        /*   IN-HP */ "喜马偕尔邦",
        /*   IN-JK */ "查谟和克什米尔",
        /*   IN-CT */ "恰蒂斯加尔邦",
        /*   IN-JH */ "贾坎德",
        /*   IN-KA */ "卡纳塔克",
        /*   IN-RJ */ "拉贾斯坦邦",
        /*   IN-OR */ "奥里萨",
        /*   IN-GJ */ "古吉拉特",
        /*   IN-WB */ "西孟加拉邦",
        /*   IN-MP */ "中央邦",
        /*   IN-TG */ "特伦甘纳邦",
        /*   IN-AP */ "安德拉邦",
        /*   IN-MH */ "马哈拉施特拉",
        /*   IN-UP */ "北方邦",
        /*   IN-PY */ "本地治里",
        /*     NSW */ "新南威尔士州",
        /*     ACT */ "澳大利亚首都特区",
        /*     JBT */ "杰维斯湾领地",
        /*   AU-NT */ "北领地",
        /*   AU-SA */ "南澳大利亚",
        /*     TAS */ "塔斯马尼亚",
        /*     VIC */ "维多利亚",
        /*   AU-WA */ "西澳大利亚",
        /*     QLD */ "昆士兰",
        /*   BR-DF */ "联邦区",
        /*   BR-SE */ "塞尔希培州",
        /*   BR-AL */ "阿拉戈斯州",
        /*   BR-RJ */ "里约热内卢州",
        /*   BR-ES */ "圣埃斯皮里图州",
        /*   BR-RN */ "北里奥格兰德州",
        /*   BR-PB */ "帕拉伊巴州",
        /*   BR-SC */ "圣卡塔琳娜州",
        /*   BR-PE */ "伯南布哥州",
        /*   BR-AP */ "阿马帕州",
        /*   BR-CE */ "塞阿拉州",
        /*   BR-AC */ "阿克里州",
        /*   BR-PR */ "巴拉那州",
        /*   BR-RR */ "罗赖马州",
        /*   BR-RO */ "朗多尼亚州",
        /*   BR-SP */ "圣保罗州",
        /*   BR-PI */ "皮奥伊州",
        /*   BR-TO */ "托坎廷斯州",
        /*   BR-RS */ "南里奥格兰德州",
        /*   BR-MA */ "马拉尼昂州",
        /*   BR-GO */ "戈亚斯州",
        /*   BR-MS */ "南马托格罗索州",
        /*   BR-BA */ "巴伊亚州",
        /*   BR-MG */ "米纳斯吉拉斯州",
        /*   BR-MT */ "马托格罗索州",
        /*   BR-PA */ "帕拉州",
        /*   BR-AM */ "亚马孙州",
        /*   US-DC */ "華盛頓哥倫比亞特區",
        /*   US-RI */ "罗得岛州",
        /*   US-DE */ "特拉华州",
        /*   US-CT */ "康涅狄格州",
        /*   US-NJ */ "新泽西州",
        /*   US-NH */ "新罕布什尔州",
        /*   US-VT */ "佛蒙特州",
        /*   US-MA */ "马萨诸塞州",
        /*   US-HI */ "夏威夷州",
        /*   US-MD */ "马里兰州",
        /*   US-WV */ "西弗吉尼亚州",
        /*   US-SC */ "南卡罗来纳州",
        /*   US-ME */ "缅因州",
        /*   US-IN */ "印第安纳州",
        /*   US-KY */ "肯塔基州",
        /*   US-TN */ "田纳西州",
        /*   US-VA */ "弗吉尼亚州",
        /*   US-OH */ "俄亥俄州",
        /*   US-PA */ "宾夕法尼亚州",
        /*   US-MS */ "密西西比州",
        /*   US-LA */ "路易斯安那州",
        /*   US-AL */ "亚拉巴马州",
        /*   US-AR */ "阿肯色州",
        /*   US-NC */ "北卡罗来纳州",
        /*   US-NY */ "纽约州",
        /*   US-IA */ "愛荷華州",
        /*   US-IL */ "伊利诺伊州",
        /*   US-GA */ "格鲁吉亚",
        /*   US-WI */ "威斯康星州",
        /*   US-FL */ "佛罗里达州",
        /*   US-MO */ "密苏里州",
        /*   US-OK */ "奧克拉荷馬州",
        /*   US-ND */ "北达科他州",
        /*   US-WA */ "华盛顿州",
        /*   US-SD */ "南达科他州",
        /*   US-NE */ "内布拉斯加州",
        /*   US-KS */ "堪萨斯州",
        /*   US-ID */ "爱达荷州",
        /*   US-UT */ "犹他州",
        /*   US-MN */ "明尼苏达州",
        /*   US-MI */ "密西根州",
        /*   US-WY */ "怀俄明州",
        /*   US-OR */ "俄勒冈州",
        /*   US-CO */ "科罗拉多州",
        /*   US-NV */ "内华达州",
        /*   US-AZ */ "亚利桑那州",
        /*   US-NM */ "新墨西哥州",
        /*   US-MT */ "蒙大拿州",
        /*   US-CA */ "加利福尼亚州",
        /*   US-TX */ "得克萨斯州",
        /*   US-AK */ "阿拉斯加州",
        /*   CA-BC */ "不列颠哥伦比亚省",
        /*   CA-AB */ "艾伯塔省",
        /*   CA-ON */ "安大略",
        /*   CA-QC */ "魁北克",
        /*   CA-SK */ "萨斯喀彻温",
        /*   CA-MB */ "马尼托巴",
        /*   CA-NL */ "纽芬兰",
        /*   CA-NB */ "新不伦瑞克",
        /*   CA-NS */ "新斯科舍省",
        /*   CA-PE */ "爱德华王子岛",
        /*   CA-YT */ "育空",
        /*   CA-NT */ "西北地区",
        /*   CA-NU */ "努纳武特",
        /*     IND */ "印度",
        /*     AUS */ "澳大利亚",
        /*     BRA */ "巴西",
        /*     USA */ "美国|美利坚合众国",
        /*     MEX */ "墨西哥",
        /*     MOW */ "莫斯科州",
        /*     SPE */ "圣彼得堡",
        /*     KGD */ "加里宁格勒州",
        /*   RU-IN */ "印古什共和国",
        /*   RU-AD */ "阿迪格共和国",
        /*   RU-SE */ "北奥塞梯 - 阿拉尼亚共和国",
        /*   RU-KB */ "卡巴尔达 - 巴尔卡共和国",
        /*   RU-KC */ "卡拉恰伊-切尔克斯共和国",
        /*   RU-CE */ "车臣共和国",
        /*   RU-CU */ "楚瓦什共和国",
        /*     IVA */ "伊万诺沃州",
        /*     LIP */ "利佩茨克州",
        /*     ORL */ "奥廖尔州",
        /*     TUL */ "图拉州",
        /*   RU-BE */ "别尔哥罗德州",
        /*     VLA */ "弗拉基米尔州",
        /*     KRS */ "库尔斯克州",
        /*     KLU */ "卡卢加州",
        /*   RU-TT */ "坦波夫州",
        /*     BRY */ "布良斯克州",
        /*     YAR */ "雅罗斯拉夫尔州",
        /*     RYA */ "梁赞州",
        /*     AST */ "阿斯特拉罕州",
        /*     MOS */ "莫斯科州",
        /*     SMO */ "斯摩棱斯克州",
        /*   RU-DA */ "达吉斯坦共和国",
        /*     VOR */ "沃罗涅日州",
        /*     NGR */ "诺夫哥罗德州",
        /*     PSK */ "普斯科夫州",
        /*     KOS */ "科斯特罗马州",
        /*     STA */ "斯塔夫罗波尔边疆区",
        /*     KDA */ "克拉斯诺达尔边疆区",
        /*   RU-KL */ "卡尔梅克共和国",
        /*     TVE */ "特维尔州",
        /*     LEN */ "列宁格勒州",
        /*     ROS */ "罗斯托夫州",
        /*     VGG */ "伏尔加格勒州",
        /*     VLG */ "沃洛格达州",
        /*     MUR */ "摩尔曼斯克州",
        /*   RU-KR */ "卡累利阿共和国",
        /*     NEN */ "涅涅茨自治区",
        /*   RU-KO */ "科米共和国",
        /*     ARK */ "阿尔汉格尔斯克州",
        /*   RU-MO */ "莫尔多维亚共和国",
        /*     NIZ */ "下诺夫哥罗德州",
        /*     PNZ */ "奔萨州",
        /*   RU-KI */ "基洛夫州",
        /*   RU-ME */ "马里埃尔共和国",
        /*     ORE */ "奥伦堡州",
        /*     ULY */ "乌里扬诺夫斯克州",
        /*   RU-PM */ "彼尔姆边疆区",
        /*   RU-BA */ "巴什科尔托斯坦共和国",
        /*   RU-UD */ "乌德穆尔特共和国",
        /*   RU-TA */ "鞑靼斯坦共和国",
        /*     SAM */ "萨马拉州",
        /*     SAR */ "萨拉托夫州",
        /*     YAN */ "亚马尔-涅涅茨自治区",
        /*   RU-KM */ "汉特曼西",
        /*     SVE */ "斯維爾德洛夫斯克州",
        /*     TYU */ "秋明州",
        /*     KGN */ "库尔干州",
        /*   RU-CH */ "车里雅宾斯克州",
        /*   RU-BU */ "布里亚特共和国",
        /*     ZAB */ "外貝加爾邊疆區",
        /*     IRK */ "伊尔库茨克州",
        /*     NVS */ "新西伯利亚州",
        /*     TOM */ "托木斯克州",
        /*     OMS */ "鄂木斯克州",
        /*   RU-KK */ "哈卡斯共和国",
        /*     KEM */ "科麦罗沃州",
        /*   RU-AL */ "阿尔泰共和国",
        /*     ALT */ "阿尔泰边疆区",
        /*   RU-TY */ "图瓦共和国",
        /*     KYA */ "克拉斯诺亚尔斯克边疆区",
        /*     MAG */ "马加丹州",
        /*     CHU */ "楚科奇自治区",
        /*     KAM */ "堪察加边疆区",
        /*     SAK */ "萨哈林州",
        /*   RU-PO */ "滨海边疆区",
        /*     YEV */ "犹太自治州",
        /*     KHA */ "哈巴罗夫斯克边疆区",
        /*     AMU */ "阿穆尔州",
        /*   RU-SA */ "萨哈共和国|雅库特共和国",
        /*     CAN */ "加拿大",
        /*     RUS */ "俄国",
        /*   CN-SH */ "上海",
        /*   CN-TJ */ "天津",
        /*   CN-BJ */ "北京",
        /*   CN-HI */ "海南",
        /*   CN-NX */ "宁夏回族",
        /*   CN-CQ */ "重庆",
        /*   CN-ZJ */ "浙江",
        /*   CN-JS */ "江苏",
        /*   CN-FJ */ "福建",
        /*   CN-AH */ "安徽",
        /*   CN-LN */ "辽宁",
        /*   CN-SD */ "山东",
        /*   CN-SX */ "山西",
        /*   CN-JX */ "江西",
        /*   CN-HA */ "河南",
        /*   CN-GZ */ "贵州",
        /*   CN-GD */ "粤",
        /*   CN-HB */ "湖北",
        /*   CN-JL */ "吉林",
        /*   CN-HE */ "河北",
        /*   CN-SN */ "陕西",
        /*   CN-NM */ "内蒙古",
        /*   CN-HL */ "黑龙江",
        /*   CN-HN */ "湖南",
        /*   CN-GX */ "广西壮族",
        /*   CN-SC */ "四川",
        /*   CN-YN */ "云南",
        /*   CN-XZ */ "西藏",
        /*   CN-GS */ "甘肃",
        /*   CN-QH */ "青海",
        /*   CN-XJ */ "新疆维吾尔族",
        /*     CHN */ "中国",
        /*     UMI */ "美國本土外小島嶼",
        /*     CPT */ "克利珀顿岛",
        /*     ATA */ "南极洲",
        /*     AAA */ "国际|地球|世界"
#else // MAPCODE_SUPPORT_LANGUAGE_CN
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_CN
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_CN_H__
