// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_KO_H__
#define __INTERNAL_TERRITORY_NAMES_KO_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_KO[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_KO // Korean
        /*     VAT */ "바티칸 시국|교황청",
        /*     MCO */ "모나코",
        /*     GIB */ "지브롤터",
        /*     TKL */ "토켈라우",
        /*     CCK */ "코코스 제도|킬링 제도",
        /*     BLM */ "생바르텔레미",
        /*     NRU */ "나우루",
        /*     TUV */ "투발루",
        /*     MAC */ "마카오",
        /*     SXM */ "신트마르턴",
        /*     MAF */ "세인트 마틴",
        /*     NFK */ "노퍽 섬|필립 섬",
        /*     PCN */ "핏케언 제도",
        /*     BVT */ "부베 섬",
        /*     BMU */ "버뮤다",
        /*     IOT */ "영국령 인도양 지역",
        /*     SMR */ "산마리노",
        /*     GGY */ "건지 섬",
        /*     AIA */ "앵귈라",
        /*     MSR */ "몬트세랫",
        /*     JEY */ "저지 섬",
        /*     CXR */ "크리스마스 섬",
        /*     WLF */ "월리스 푸투나|푸투나",
        /*     VGB */ "영국령 버진아일랜드|버진아일랜드 영국령",
        /*     LIE */ "리히텐슈타인",
        /*     ABW */ "아루바",
        /*     MHL */ "마셜 제도",
        /*     ASM */ "아메리칸사모아",
        /*     COK */ "쿡 제도",
        /*     SPM */ "생피에르 미클롱",
        /*     NIU */ "니우에",
        /*     KNA */ "세인트키츠 네비스|네비스",
        /*     CYM */ "케이맨 제도",
        /*     BES */ "보네르, 세인트 유스 타티 우스 및 사바|사바|세인트 유스 타티 우스",
        /*     MDV */ "몰디브",
        /*     SHN */ "세인트헬레나, 승천과 트리스탄 다 쿠냐|승천|트리스탄 다 쿠냐",
        /*     MLT */ "몰타",
        /*     GRD */ "그레나다",
        /*     VIR */ "미국령 버진아일랜드|버진아일랜드 미국령",
        /*     MYT */ "마요트",
        /*     SJM */ "스발바르 얀마옌|얀마옌",
        /*     VCT */ "세인트빈센트 그레나딘|그레나딘",
        /*     HMD */ "허드 맥도널드 제도",
        /*     BRB */ "바베이도스",
        /*     ATG */ "앤티가 바부 다|바부 다",
        /*     CUW */ "쿠라 카오",
        /*     SYC */ "세이셸",
        /*     PLW */ "팔라우",
        /*     MNP */ "북마리아나 제도",
        /*     AND */ "안도라",
        /*     GUM */ "괌",
        /*     IMN */ "맨 섬",
        /*     LCA */ "세인트루시아",
        /*     FSM */ "미크로네시아 연방",
        /*     SGP */ "싱가포르",
        /*     TON */ "통가",
        /*     DMA */ "도미니카 연방",
        /*     BHR */ "바레인",
        /*     KIR */ "키리바시",
        /*     TCA */ "터크스 케이커스 제도",
        /*     STP */ "상투메 프린시페|프린시페",
        /*     HKG */ "홍콩",
        /*     MTQ */ "마르티니크",
        /*     FRO */ "페로 제도",
        /*     GLP */ "과들루프",
        /*     COM */ "코모로",
        /*     MUS */ "모리셔스",
        /*     REU */ "레위니옹",
        /*     LUX */ "룩셈부르크",
        /*     WSM */ "사모아",
        /*     SGS */ "사우스조지아 및 사우스 샌드위치 제도|사우스 샌드위치 제도",
        /*     PYF */ "프랑스령 폴리네시아",
        /*     CPV */ "카보베르데",
        /*     TTO */ "트리니다드 토바고",
        /*     BRN */ "브루나이",
        /*     ATF */ "프랑스령 남방 및 남극",
        /*     PRI */ "푸에르토리코",
        /*     CYP */ "키프로스",
        /*     LBN */ "레바논",
        /*     JAM */ "자메이카",
        /*     GMB */ "감비아",
        /*     QAT */ "카타르",
        /*     FLK */ "포클랜드 제도",
        /*     VUT */ "바누아투",
        /*     MNE */ "몬테네그로",
        /*     BHS */ "바하마",
        /*     TLS */ "동티모르",
        /*     SWZ */ "스와질란드",
        /*     KWT */ "쿠웨이트",
        /*     FJI */ "피지",
        /*     NCL */ "누벨칼레도니|뉴 칼레도니아",
        /*     SVN */ "슬로베니아",
        /*     ISR */ "이스라엘",
        /*     PSE */ "팔레스타인 자치",
        /*     SLV */ "엘살바도르",
        /*     BLZ */ "벨리즈",
        /*     DJI */ "지부티",
        /*     MKD */ "마케도니아 공화국",
        /*     RWA */ "르완다",
        /*     HTI */ "아이티",
        /*     BDI */ "부룬디",
        /*     GNQ */ "적도 기니",
        /*     ALB */ "알바니아",
        /*     SLB */ "솔로몬 제도",
        /*     ARM */ "아르메니아",
        /*     LSO */ "레소토",
        /*     BEL */ "벨기에",
        /*     MDA */ "몰도바",
        /*     GNB */ "기니비사우",
        /*     TWN */ "타이완",
        /*     BTN */ "부탄",
        /*     CHE */ "스위스",
        /*     NLD */ "네덜란드",
        /*     DNK */ "덴마크",
        /*     EST */ "에스토니아",
        /*     DOM */ "도미니카 공화국",
        /*     SVK */ "슬로바키아",
        /*     CRI */ "코스타리카",
        /*     BIH */ "보스니아 헤르체고비나",
        /*     HRV */ "크로아티아",
        /*     TGO */ "토고",
        /*     LVA */ "라트비아",
        /*     LTU */ "리투아니아",
        /*     LKA */ "스리랑카",
        /*     GEO */ "조지아",
        /*     IRL */ "아일랜드",
        /*     SLE */ "시에라리온",
        /*     PAN */ "파나마",
        /*     CZE */ "체코",
        /*     GUF */ "프랑스령 기아나",
        /*     ARE */ "아랍에미리트",
        /*     AUT */ "오스트리아",
        /*     AZE */ "아제르바이잔",
        /*     SRB */ "세르비아",
        /*     JOR */ "요르단",
        /*     PRT */ "포르투갈",
        /*     HUN */ "헝가리",
        /*     KOR */ "대한민국",
        /*     ISL */ "아이슬란드",
        /*     GTM */ "과테말라",
        /*     CUB */ "쿠바",
        /*     BGR */ "불가리아",
        /*     LBR */ "라이베리아",
        /*     HND */ "온두라스",
        /*     BEN */ "베냉",
        /*     ERI */ "에리트레아",
        /*     MWI */ "말라위",
        /*     PRK */ "조선민주주의인민공화국",
        /*     NIC */ "니카라과",
        /*     GRC */ "그리스",
        /*     TJK */ "타지키스탄",
        /*     BGD */ "방글라데시",
        /*     NPL */ "네팔",
        /*     TUN */ "튀니지",
        /*     SUR */ "수리남",
        /*     URY */ "우루과이",
        /*     KHM */ "캄보디아",
        /*     SYR */ "시리아",
        /*     SEN */ "세네갈",
        /*     KGZ */ "키르기스스탄",
        /*     BLR */ "벨라루스",
        /*     GUY */ "가이아나",
        /*     LAO */ "라오스",
        /*     ROU */ "루마니아",
        /*     GHA */ "가나",
        /*     UGA */ "우간다",
        /*     GBR */ "영국|스코틀랜드|북 아일랜드|아일랜드, 북",
        /*     GIN */ "기니",
        /*     ECU */ "에콰도르",
        /*     ESH */ "서부 사하라",
        /*     GAB */ "가봉",
        /*     NZL */ "뉴질랜드",
        /*     BFA */ "부르키나파소",
        /*     PHL */ "필리핀",
        /*     ITA */ "이탈리아",
        /*     OMN */ "오만",
        /*     POL */ "폴란드",
        /*     CIV */ "코트디부아르",
        /*     NOR */ "노르웨이",
        /*     MYS */ "말레이시아",
        /*     VNM */ "베트남",
        /*     FIN */ "핀란드",
        /*     COG */ "콩고 공화국",
        /*     DEU */ "독일",
        /*     JPN */ "일본",
        /*     ZWE */ "짐바브웨",
        /*     PRY */ "파라과이",
        /*     IRQ */ "이라크",
        /*     MAR */ "모로코",
        /*     UZB */ "우즈베키스탄",
        /*     SWE */ "스웨덴",
        /*     PNG */ "파푸아뉴기니",
        /*     CMR */ "카메룬",
        /*     TKM */ "투르크메니스탄",
        /*     ESP */ "스페인",
        /*     THA */ "태국",
        /*     YEM */ "예멘",
        /*     FRA */ "프랑스",
        /*     ALA */ "올란드 제도",
        /*     KEN */ "케냐",
        /*     BWA */ "보츠와나",
        /*     MDG */ "마다가스카르",
        /*     UKR */ "우크라이나",
        /*     SSD */ "남수단",
        /*     CAF */ "중앙아프리카 공화국",
        /*     SOM */ "소말리아",
        /*     AFG */ "아프가니스탄",
        /*     MMR */ "미얀마|버마",
        /*     ZMB */ "잠비아",
        /*     CHL */ "칠레",
        /*     TUR */ "터키",
        /*     PAK */ "파키스탄",
        /*     MOZ */ "모잠비크",
        /*     NAM */ "나미비아",
        /*     VEN */ "베네수엘라",
        /*     NGA */ "나이지리아",
        /*     TZA */ "탄자니아",
        /*     EGY */ "이집트",
        /*     MRT */ "모리타니",
        /*     BOL */ "볼리비아",
        /*     ETH */ "에티오피아",
        /*     COL */ "콜롬비아",
        /*     ZAF */ "남아프리카 공화국",
        /*     MLI */ "말리",
        /*     AGO */ "앙골라",
        /*     NER */ "니제르",
        /*     TCD */ "차드",
        /*     PER */ "페루",
        /*     MNG */ "몽골",
        /*     IRN */ "이란",
        /*     LBY */ "리비아",
        /*     SDN */ "수단",
        /*     IDN */ "인도네시아",
        /*     DIF */ "연방 지구",
        /*     TLA */ "틀 락스 칼라",
        /*     MOR */ "모렐 로스",
        /*     AGU */ "아과 스 칼리 엔 테스",
        /*   MX-CL */ "콜리 마",
        /*     QUE */ "케 레타로",
        /*     HID */ "이달고 주",
        /*   MX-MX */ "멕시코 주",
        /*     TAB */ "타바스코",
        /*     NAY */ "나야 릿",
        /*     GUA */ "과 나후 아토",
        /*     PUE */ "푸에블라",
        /*     YUC */ "유카탄",
        /*     ROO */ "킨 타나로",
        /*     SIN */ "시날로아",
        /*     CAM */ "캄 페체",
        /*     MIC */ "미초 아깐",
        /*     SLP */ "산 루이스 포토",
        /*     GRO */ "게레로",
        /*     NLE */ "누에 보 레온",
        /*     BCN */ "바하 캘리포니아",
        /*     VER */ "베라 크루즈",
        /*     CHP */ "치아파스",
        /*     BCS */ "바하 칼리 포르 니아 수르",
        /*     ZAC */ "사 카테 카스",
        /*     JAL */ "할리 스코",
        /*     TAM */ "타마 울리 파스",
        /*     OAX */ "오악 사카",
        /*     DUR */ "두 랑고",
        /*     COA */ "코아 우일",
        /*     SON */ "노라",
        /*     CHH */ "치와와",
        /*     GRL */ "그린란드",
        /*     SAU */ "사우디아라비아",
        /*     COD */ "콩고 민주 공화국",
        /*     DZA */ "알제리",
        /*     KAZ */ "카자흐스탄",
        /*     ARG */ "아르헨티나",
        /*   IN-DD */ "다만 디우",
        /*   IN-DN */ "다 드라 나가르 하 벨리",
        /*   IN-CH */ "찬디 가르",
        /*   IN-AN */ "안다만 니코 바르",
        /*   IN-LD */ "락 샤드 윕",
        /*   IN-DL */ "델리",
        /*   IN-ML */ "메갈 라야",
        /*   IN-NL */ "나갈 랜드",
        /*   IN-MN */ "마니 푸르",
        /*   IN-TR */ "트리 푸라",
        /*   IN-MZ */ "미조람",
        /*   IN-SK */ "시킴",
        /*   IN-PB */ "펀 자브",
        /*   IN-HR */ "하리 아나",
        /*   IN-AR */ "아루나 찰 프라데시",
        /*   IN-AS */ "아삼",
        /*   IN-BR */ "비하르",
        /*   IN-UT */ "우타 라칸",
        /*   IN-GA */ "고아",
        /*   IN-KL */ "케 랄라",
        /*   IN-TN */ "타밀 나두",
        /*   IN-HP */ "히 마찰 프라데시",
        /*   IN-JK */ "카슈미르",
        /*   IN-CT */ "차 티스 가르",
        /*   IN-JH */ "즈 하르 한드",
        /*   IN-KA */ "카르 나 타카",
        /*   IN-RJ */ "라자스탄",
        /*   IN-OR */ "오리사 주|오리",
        /*   IN-GJ */ "구자라트",
        /*   IN-WB */ "웨스트 벵갈",
        /*   IN-MP */ "마디 아 프라데시",
        /*   IN-TG */ "텔랑 가나 주",
        /*   IN-AP */ "안드라 프라데시",
        /*   IN-MH */ "마하라 슈트라",
        /*   IN-UP */ "우타르 프라데시",
        /*   IN-PY */ "푸두 체리|폰디 체리",
        /*     NSW */ "뉴 사우스 웨일즈",
        /*     ACT */ "호주 수도 특별 자치구",
        /*     JBT */ "저비스 베이 준주",
        /*   AU-NT */ "노던 테리토리",
        /*   AU-SA */ "사우스 오스트레일리아",
        /*     TAS */ "태즈 메이 니아",
        /*     VIC */ "빅토리아",
        /*   AU-WA */ "웨스턴 오스트레일리아",
        /*     QLD */ "퀸즐랜드",
        /*   BR-DF */ "디스트 리토 페데 랄",
        /*   BR-SE */ "세르 지페",
        /*   BR-AL */ "알라고 아스",
        /*   BR-RJ */ "리오 데 자네이로",
        /*   BR-ES */ "에스피 리토 산토",
        /*   BR-RN */ "리오 그란데 노르 테",
        /*   BR-PB */ "파라이",
        /*   BR-SC */ "산타 카타리나",
        /*   BR-PE */ "페르 남부 쿠",
        /*   BR-AP */ "아마 파",
        /*   BR-CE */ "아라",
        /*   BR-AC */ "아크리 주",
        /*   BR-PR */ "파라나",
        /*   BR-RR */ "로라 이마",
        /*   BR-RO */ "론도",
        /*   BR-SP */ "상 파울로",
        /*   BR-PI */ "피아 우이",
        /*   BR-TO */ "토칸 틴스",
        /*   BR-RS */ "리오 그란데도 술을",
        /*   BR-MA */ "마라 냐웅",
        /*   BR-GO */ "고이 아스",
        /*   BR-MS */ "마투 그로 수두 술 주",
        /*   BR-BA */ "바이아",
        /*   BR-MG */ "미나스 제 라이스",
        /*   BR-MT */ "마투 그로 수",
        /*   BR-PA */ "파라",
        /*   BR-AM */ "아마 조나스",
        /*   US-DC */ "워싱턴 D.C.",
        /*   US-RI */ "로드아일랜드",
        /*   US-DE */ "델라웨어",
        /*   US-CT */ "코네티컷",
        /*   US-NJ */ "뉴저지",
        /*   US-NH */ "뉴햄프셔",
        /*   US-VT */ "버몬트",
        /*   US-MA */ "매사추세츠",
        /*   US-HI */ "하와이",
        /*   US-MD */ "메릴랜드",
        /*   US-WV */ "웨스트버지니아",
        /*   US-SC */ "사우스캐롤라이나",
        /*   US-ME */ "메인",
        /*   US-IN */ "인디애나",
        /*   US-KY */ "켄터키",
        /*   US-TN */ "테네시",
        /*   US-VA */ "버지니아",
        /*   US-OH */ "오하이오",
        /*   US-PA */ "펜실베이니아",
        /*   US-MS */ "미시시피",
        /*   US-LA */ "루이지애나",
        /*   US-AL */ "앨라배마",
        /*   US-AR */ "아칸소",
        /*   US-NC */ "노스캐롤라이나",
        /*   US-NY */ "뉴욕",
        /*   US-IA */ "아이오와",
        /*   US-IL */ "일리노이",
        /*   US-GA */ "조지아",
        /*   US-WI */ "위스콘신",
        /*   US-FL */ "플로리다",
        /*   US-MO */ "미주리",
        /*   US-OK */ "오클라호마",
        /*   US-ND */ "노스다코타",
        /*   US-WA */ "워싱턴",
        /*   US-SD */ "사우스다코타",
        /*   US-NE */ "네브래스카",
        /*   US-KS */ "캔자스",
        /*   US-ID */ "아이다호",
        /*   US-UT */ "유타",
        /*   US-MN */ "미네소타",
        /*   US-MI */ "미시간",
        /*   US-WY */ "와이오밍",
        /*   US-OR */ "오리건",
        /*   US-CO */ "콜로라도",
        /*   US-NV */ "네바다",
        /*   US-AZ */ "애리조나",
        /*   US-NM */ "뉴멕시코",
        /*   US-MT */ "몬태나",
        /*   US-CA */ "캘리포니아",
        /*   US-TX */ "텍사스",
        /*   US-AK */ "알래스카",
        /*   CA-BC */ "브리티시 컬럼비아",
        /*   CA-AB */ "앨버타",
        /*   CA-ON */ "온타리오",
        /*   CA-QC */ "퀘벡",
        /*   CA-SK */ "서스 캐처 원",
        /*   CA-MB */ "매니토바",
        /*   CA-NL */ "뉴 펀들 랜드",
        /*   CA-NB */ "뉴 브런 즈윅",
        /*   CA-NS */ "노바 스코샤",
        /*   CA-PE */ "프린스 에드워드 아일랜드",
        /*   CA-YT */ "유콘",
        /*   CA-NT */ "노스 웨스트 준주",
        /*   CA-NU */ "누나 부트 준주",
        /*     IND */ "인도",
        /*     AUS */ "오스트레일리아",
        /*     BRA */ "브라질",
        /*     USA */ "미국",
        /*     MEX */ "멕시코",
        /*     MOW */ "모스크바",
        /*     SPE */ "상트 페테르부르크",
        /*     KGD */ "칼리닌그라드 주",
        /*   RU-IN */ "잉 구세 티아 공화국",
        /*   RU-AD */ "아디 게야 공화국",
        /*   RU-SE */ "세 베로 오 세티 야 공화국 공화국",
        /*   RU-KB */ "카 바르 디노 발 카르 공화국",
        /*   RU-KC */ "카라 차 예보 체르 케스 카야 공화국",
        /*   RU-CE */ "체첸어 공화국",
        /*   RU-CU */ "추바슈어 공화국",
        /*     IVA */ "이바노 보 주",
        /*     LIP */ "리페 츠크 주",
        /*     ORL */ "오룔 주",
        /*     TUL */ "툴라 주",
        /*   RU-BE */ "벨고로드 주",
        /*     VLA */ "블라디미르 주",
        /*     KRS */ "쿠르스크 주",
        /*     KLU */ "칼루가 주",
        /*   RU-TT */ "탐 보프 주",
        /*     BRY */ "브랸 스크 주",
        /*     YAR */ "야로 슬라 블 주",
        /*     RYA */ "랴잔 주",
        /*     AST */ "아스트라한 주",
        /*     MOS */ "모스크바 주",
        /*     SMO */ "스몰 렌 스크 주",
        /*   RU-DA */ "다게 스탄 공화국",
        /*     VOR */ "보 로네시 주",
        /*     NGR */ "노브 고로드 주",
        /*     PSK */ "프 스코프 주",
        /*     KOS */ "코스트 로마 주",
        /*     STA */ "스타 브로 폴 크라이",
        /*     KDA */ "크라 스노 다르 크라이",
        /*   RU-KL */ "칼 미크 공화국",
        /*     TVE */ "트 베리 주",
        /*     LEN */ "레닌 그라드 주",
        /*     ROS */ "로스토프 주",
        /*     VGG */ "볼고그라드 주",
        /*     VLG */ "볼 로그 다 주",
        /*     MUR */ "무르만스크 주",
        /*   RU-KR */ "카렐 리야 공화국",
        /*     NEN */ "네 네츠 자치구",
        /*   RU-KO */ "코미 공화국",
        /*     ARK */ "아르 한 겔 스크 주",
        /*   RU-MO */ "모르도 바 공화국",
        /*     NIZ */ "니즈니 노브 고로드 주",
        /*     PNZ */ "펜자 주",
        /*   RU-KI */ "키로프 주",
        /*   RU-ME */ "마리 엘 공화국",
        /*     ORE */ "오렌 부르크 주",
        /*     ULY */ "울리 야놉 스크 주",
        /*   RU-PM */ "페름 지방",
        /*   RU-BA */ "바시 키르 공화국",
        /*   RU-UD */ "우드 무 르트 공화국",
        /*   RU-TA */ "타타르 공화국",
        /*     SAM */ "사마라 주",
        /*     SAR */ "사라 토프 주",
        /*     YAN */ "야말로 - 네 네츠",
        /*   RU-KM */ "한티 Mansi",
        /*     SVE */ "스 베르들 롭 스크 주",
        /*     TYU */ "튜멘 주",
        /*     KGN */ "쿠 르간 주",
        /*   RU-CH */ "첼 랴빈 스크 주",
        /*   RU-BU */ "부랴 트 공화국",
        /*     ZAB */ "치타 지역",
        /*     IRK */ "이르쿠츠크 주",
        /*     NVS */ "노보시비르스크 주",
        /*     TOM */ "톰 스크 주",
        /*     OMS */ "옴 스크 주",
        /*   RU-KK */ "하 카스 공화국",
        /*     KEM */ "케메 로보 주",
        /*   RU-AL */ "알타이 공화국",
        /*     ALT */ "알타이 크라이",
        /*   RU-TY */ "투바 공화국",
        /*     KYA */ "크라스 노야 르 스크 크라이",
        /*     MAG */ "마가 단 주",
        /*     CHU */ "추 코트 카 자치구",
        /*     KAM */ "캄차카 지방",
        /*     SAK */ "사할린 주",
        /*   RU-PO */ "프리 모르 스키 크라이",
        /*     YEV */ "유대인 자치주",
        /*     KHA */ "하바롭스크 지방",
        /*     AMU */ "아무르 주",
        /*   RU-SA */ "사하 공화국|야쿠 티아 공화국",
        /*     CAN */ "캐나다",
        /*     RUS */ "러시아",
        /*   CN-SH */ "상하이",
        /*   CN-TJ */ "천진",
        /*   CN-BJ */ "베이징",
        /*   CN-HI */ "하이난",
        /*   CN-NX */ "닝샤 후이족",
        /*   CN-CQ */ "충칭",
        /*   CN-ZJ */ "절강",
        /*   CN-JS */ "강소",
        /*   CN-FJ */ "복건",
        /*   CN-AH */ "안후이",
        /*   CN-LN */ "랴오닝",
        /*   CN-SD */ "산동",
        /*   CN-SX */ "산서",
        /*   CN-JX */ "장시",
        /*   CN-HA */ "허난",
        /*   CN-GZ */ "구이 저우",
        /*   CN-GD */ "광동",
        /*   CN-HB */ "호북",
        /*   CN-JL */ "길림",
        /*   CN-HE */ "허베이",
        /*   CN-SN */ "산시",
        /*   CN-NM */ "내몽골|네이 몽골",
        /*   CN-HL */ "헤이룽장",
        /*   CN-HN */ "호남",
        /*   CN-GX */ "광시 좡어",
        /*   CN-SC */ "쓰촨",
        /*   CN-YN */ "운남",
        /*   CN-XZ */ "서장|티베트",
        /*   CN-GS */ "간쑤",
        /*   CN-QH */ "칭하이",
        /*   CN-XJ */ "신장 위구르어",
        /*     CHN */ "중국",
        /*     UMI */ "미국령 군소 제도",
        /*     CPT */ "클리퍼 턴 섬",
        /*     ATA */ "남극",
        /*     AAA */ "국제|세계|지구"
#else // MAPCODE_SUPPORT_LANGUAGE_KO
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_KO
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_KO_H__
