// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_PT_H__
#define __INTERNAL_TERRITORY_NAMES_PT_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_PT[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_PT // Portuguese
        /*     VAT */ "Vaticano|Cidade do Vaticano|Santa Sé",
        /*     MCO */ "Mónaco",
        /*     GIB */ "Gibraltar",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Ilhas Cocos|Ilhas Keeling",
        /*     BLM */ "Saint-Barthelemy|São Bartolomeu",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Macau",
        /*     SXM */ "Sint Maarten",
        /*     MAF */ "Saint Martin",
        /*     NFK */ "Ilhas Norfolk e Philip|Ilha de Philip",
        /*     PCN */ "Ilhas Pitcairn",
        /*     BVT */ "Ilha de Bouvet",
        /*     BMU */ "Bermudas",
        /*     IOT */ "Território Britânico do Oceano Índico",
        /*     SMR */ "San Marino",
        /*     GGY */ "Guernsey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Ilha do Natal",
        /*     WLF */ "Wallis e Futuna|Futuna",
        /*     VGB */ "Ilhas Virgens Britânicas",
        /*     LIE */ "Liechtenstein",
        /*     ABW */ "Aruba",
        /*     MHL */ "Ilhas Marshall",
        /*     ASM */ "Samoa Americana",
        /*     COK */ "Ilhas Cook",
        /*     SPM */ "Saint Pierre e Miquelon|Miquelon|São Pierre e Miquelon",
        /*     NIU */ "Niue",
        /*     KNA */ "São Cristóvão e Névis|Névis",
        /*     CYM */ "Ilhas Cayman",
        /*     BES */ "Bonaire, St Eustatuis e Saba|Saba|St Eustatius",
        /*     MDV */ "Maldivas",
        /*     SHN */ "Santa Helena, Ascensão e Tristão da Cunha|Ascensão|Tristão da Cunha",
        /*     MLT */ "Malta",
        /*     GRD */ "Grenada",
        /*     VIR */ "Ilhas Virgens Americanas",
        /*     MYT */ "Mayotte",
        /*     SJM */ "Svalbard e Jan Mayen|Jan Mayen",
        /*     VCT */ "São Vicente e Granadinas|Grenadines",
        /*     HMD */ "Ilhas Heard e Ilhas McDonald|Ilhas McDonald",
        /*     BRB */ "Barbados",
        /*     ATG */ "Antígua e Barbuda|Barbuda",
        /*     CUW */ "Curaçao",
        /*     SYC */ "Seychelles",
        /*     PLW */ "Palau",
        /*     MNP */ "Marianas Setentrionais",
        /*     AND */ "Andorra",
        /*     GUM */ "Guam",
        /*     IMN */ "Ilha de Man",
        /*     LCA */ "Santa Lúcia",
        /*     FSM */ "Micronésia|Estados Federados da Micronésia",
        /*     SGP */ "Cingapura",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominica",
        /*     BHR */ "Bahrein",
        /*     KIR */ "Quiribati",
        /*     TCA */ "Ilhas Turcas e Caicos|Ilhas Caicos",
        /*     STP */ "São Tomé e Príncipe|Principe",
        /*     HKG */ "Hong Kong",
        /*     MTQ */ "Martinica",
        /*     FRO */ "Ilhas Faroe",
        /*     GLP */ "Guadalupe",
        /*     COM */ "Comores",
        /*     MUS */ "Maurício",
        /*     REU */ "Reunião",
        /*     LUX */ "Luxemburgo",
        /*     WSM */ "Samoa",
        /*     SGS */ "Geórgia do Sul e Ilhas Sandwich do Sul|Ilhas Sandwich do Sul",
        /*     PYF */ "Polinésia Francesa",
        /*     CPV */ "Cabo Verde",
        /*     TTO */ "Trinidad e Tobago|Tobago",
        /*     BRN */ "Brunei",
        /*     ATF */ "Territórios Franceses do Sul e Antárctico",
        /*     PRI */ "Porto Rico",
        /*     CYP */ "Chipre",
        /*     LBN */ "Líbano",
        /*     JAM */ "Jamaica",
        /*     GMB */ "Gâmbia",
        /*     QAT */ "Catar",
        /*     FLK */ "Ilhas Falkland",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Montenegro",
        /*     BHS */ "Bahamas",
        /*     TLS */ "Timor Leste",
        /*     SWZ */ "Suazilândia",
        /*     KWT */ "Kuwait",
        /*     FJI */ "Ilhas Fiji|Fiji",
        /*     NCL */ "Nova Caledônia",
        /*     SVN */ "Eslovênia",
        /*     ISR */ "Israel",
        /*     PSE */ "Território Palestino",
        /*     SLV */ "El Salvador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Djibouti",
        /*     MKD */ "Macedônia",
        /*     RWA */ "Ruanda",
        /*     HTI */ "Haiti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Guiné Equatorial",
        /*     ALB */ "Albânia",
        /*     SLB */ "Ilhas Salomão",
        /*     ARM */ "Armênia",
        /*     LSO */ "Lesoto",
        /*     BEL */ "Bélgica",
        /*     MDA */ "Moldávia",
        /*     GNB */ "Guiné-Bissau",
        /*     TWN */ "Taiwan",
        /*     BTN */ "Butão",
        /*     CHE */ "Suíça",
        /*     NLD */ "Holanda",
        /*     DNK */ "Dinamarca",
        /*     EST */ "Estônia",
        /*     DOM */ "República Dominicana",
        /*     SVK */ "Eslováquia",
        /*     CRI */ "Costa Rica",
        /*     BIH */ "Bósnia e Herzegovina",
        /*     HRV */ "Croácia",
        /*     TGO */ "Togo",
        /*     LVA */ "Letônia",
        /*     LTU */ "Lituânia",
        /*     LKA */ "Sri Lanka",
        /*     GEO */ "Geórgia",
        /*     IRL */ "Irlanda",
        /*     SLE */ "Serra Leoa",
        /*     PAN */ "Panamá",
        /*     CZE */ "República Checa",
        /*     GUF */ "Guiana Francesa",
        /*     ARE */ "Emirados Árabes Unidos",
        /*     AUT */ "Áustria",
        /*     AZE */ "Azerbaijão",
        /*     SRB */ "Sérvia",
        /*     JOR */ "Jordânia",
        /*     PRT */ "Portugal",
        /*     HUN */ "Hungria",
        /*     KOR */ "Coreia do Sul",
        /*     ISL */ "Islândia",
        /*     GTM */ "Guatemala",
        /*     CUB */ "Cuba",
        /*     BGR */ "Bulgária",
        /*     LBR */ "Libéria",
        /*     HND */ "Honduras",
        /*     BEN */ "Benin",
        /*     ERI */ "Eritreia",
        /*     MWI */ "Malawi",
        /*     PRK */ "Coreia do Norte",
        /*     NIC */ "Nicarágua",
        /*     GRC */ "Grécia",
        /*     TJK */ "Tajiquistão",
        /*     BGD */ "Bangladesh",
        /*     NPL */ "Nepal",
        /*     TUN */ "Tunísia",
        /*     SUR */ "Suriname",
        /*     URY */ "Uruguai",
        /*     KHM */ "Camboja",
        /*     SYR */ "Síria",
        /*     SEN */ "Senegal",
        /*     KGZ */ "Quirguistão",
        /*     BLR */ "Bielorrússia",
        /*     GUY */ "Guiana",
        /*     LAO */ "Laos",
        /*     ROU */ "Roménia",
        /*     GHA */ "Gana",
        /*     UGA */ "Uganda",
        /*     GBR */ "Reino Unido|Escócia|Grã-Bretanha|Irlanda do Norte",
        /*     GIN */ "Guiné",
        /*     ECU */ "Equador",
        /*     ESH */ "Sahara Ocidental|Saharaui",
        /*     GAB */ "Gabão",
        /*     NZL */ "Nova Zelândia",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Filipinas",
        /*     ITA */ "Itália",
        /*     OMN */ "Omã",
        /*     POL */ "Polônia",
        /*     CIV */ "Costa do Marfim",
        /*     NOR */ "Noruega",
        /*     MYS */ "Malásia",
        /*     VNM */ "Vietnã",
        /*     FIN */ "Finlândia",
        /*     COG */ "Congo-Brazzaville",
        /*     DEU */ "Alemanha",
        /*     JPN */ "Japão",
        /*     ZWE */ "Zimbábue",
        /*     PRY */ "Paraguai",
        /*     IRQ */ "Iraque",
        /*     MAR */ "Marrocos",
        /*     UZB */ "Uzbequistão",
        /*     SWE */ "Suécia",
        /*     PNG */ "Papua Nova Guiné",
        /*     CMR */ "Camarões",
        /*     TKM */ "Turcomenistão",
        /*     ESP */ "Espanha",
        /*     THA */ "Tailândia",
        /*     YEM */ "Iémen",
        /*     FRA */ "França",
        /*     ALA */ "Ilhas Aaland",
        /*     KEN */ "Quênia",
        /*     BWA */ "Botswana",
        /*     MDG */ "Madagáscar",
        /*     UKR */ "Ucrânia",
        /*     SSD */ "Sudão do Sul",
        /*     CAF */ "República Centro-Africana",
        /*     SOM */ "Somália",
        /*     AFG */ "Afeganistão",
        /*     MMR */ "Mianmar|Birmânia",
        /*     ZMB */ "Zâmbia",
        /*     CHL */ "Chile",
        /*     TUR */ "Turquia",
        /*     PAK */ "Paquistão",
        /*     MOZ */ "Moçambique",
        /*     NAM */ "Namíbia",
        /*     VEN */ "Venezuela",
        /*     NGA */ "Nigéria",
        /*     TZA */ "Tanzânia",
        /*     EGY */ "Egito",
        /*     MRT */ "Mauritânia",
        /*     BOL */ "Bolívia",
        /*     ETH */ "Etiópia",
        /*     COL */ "Colômbia",
        /*     ZAF */ "África do Sul",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Níger",
        /*     TCD */ "Chade",
        /*     PER */ "Peru",
        /*     MNG */ "Mongólia",
        /*     IRN */ "Irã",
        /*     LBY */ "Líbia",
        /*     SDN */ "Sudão",
        /*     IDN */ "Indonésia",
        /*     DIF */ "Distrito Federal",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Queretaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "Estado do México|México, Estado do",
        /*     TAB */ "Tabasco",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Iucatã",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacan",
        /*     SLP */ "San Luis Potosí",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo Leon",
        /*     BCN */ "Baja California",
        /*     VER */ "Veracruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Baja California Sur",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Durango",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Gronelândia",
        /*     SAU */ "Arábia Saudita",
        /*     COD */ "Congo-Kinshasa",
        /*     DZA */ "Argélia",
        /*     KAZ */ "Cazaquistão",
        /*     ARG */ "Argentina",
        /*   IN-DD */ "Damão e Diu",
        /*   IN-DN */ "Dadra e Nagar Haveli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman e Nicobar",
        /*   IN-LD */ "Lakshadweep",
        /*   IN-DL */ "Délhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Tripura",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Punjab",
        /*   IN-HR */ "Haryana",
        /*   IN-AR */ "Arunachal Pradesh",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarakhand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Jammu e Caxemira|Caxemira",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Odisha|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Bengala Ocidental",
        /*   IN-MP */ "Madhya Pradesh",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andhra Pradesh",
        /*   IN-MH */ "Maharashtra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Puducherry",
        /*     NSW */ "Nova Gales do Sul",
        /*     ACT */ "Território Capital da Australia",
        /*     JBT */ "Território de Jervis Bay",
        /*   AU-NT */ "Território do Norte",
        /*   AU-SA */ "Sul da Austrália",
        /*     TAS */ "Tasmânia",
        /*     VIC */ "Victoria",
        /*   AU-WA */ "Austrália Ocidental",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "Distrito Federal",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espirito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraíba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambuco",
        /*   BR-AP */ "Amapa",
        /*   BR-CE */ "Ceará",
        /*   BR-AC */ "Acre",
        /*   BR-PR */ "Paraná",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondônia",
        /*   BR-SP */ "São Paulo",
        /*   BR-PI */ "Piaui",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhão",
        /*   BR-GO */ "Goias",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso",
        /*   BR-PA */ "Pára",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "Distrito de Colúmbia",
        /*   US-RI */ "Rhode Island",
        /*   US-DE */ "Delaware",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "Nova Jérsei",
        /*   US-NH */ "Nova Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Havaí",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "Virgínia Ocidental",
        /*   US-SC */ "Carolina do Sul",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indiana",
        /*   US-KY */ "Kentucky",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Virgínia",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pensilvânia",
        /*   US-MS */ "Mississippi",
        /*   US-LA */ "Luisiana",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkansas",
        /*   US-NC */ "Carolina do Norte",
        /*   US-NY */ "Nova Iorque",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Illinois",
        /*   US-GA */ "Geórgia",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Flórida",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "Dakota do Norte",
        /*   US-WA */ "Washington",
        /*   US-SD */ "Dakota do Sul",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kansas",
        /*   US-ID */ "Idaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Wyoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Colorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "Novo México",
        /*   US-MT */ "Montana",
        /*   US-CA */ "Califórnia",
        /*   US-TX */ "Texas",
        /*   US-AK */ "Alasca",
        /*   CA-BC */ "Columbia Britânica",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontário",
        /*   CA-QC */ "Quebec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Terra Nova",
        /*   CA-NB */ "Novo Brunswick",
        /*   CA-NS */ "Nova Escócia",
        /*   CA-PE */ "Ilha Principe Edward",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Territórios do Noroeste",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "Índia",
        /*     AUS */ "Austrália",
        /*     BRA */ "Brasil",
        /*     USA */ "EUA|Estados Unidos da América|América",
        /*     MEX */ "México",
        /*     MOW */ "Moscou",
        /*     SPE */ "São Petersburgo",
        /*     KGD */ "Kaliningrad Oblast",
        /*   RU-IN */ "Ingushetia Republic",
        /*   RU-AD */ "República de Adygea",
        /*   RU-SE */ "República da Ossétia do Norte-Alania",
        /*   RU-KB */ "República de Kabardino-Balkar",
        /*   RU-KC */ "República Karachay-Cherkess",
        /*   RU-CE */ "República Chechena",
        /*   RU-CU */ "República de Chuvash",
        /*     IVA */ "Ivanovo Oblast",
        /*     LIP */ "Lipetsk Oblast",
        /*     ORL */ "Oryol Oblast",
        /*     TUL */ "Tula Oblast",
        /*   RU-BE */ "Belgorod Oblast",
        /*     VLA */ "Vladimir Oblast",
        /*     KRS */ "Oblast de Kursk",
        /*     KLU */ "Kaluga Oblast",
        /*   RU-TT */ "Tambov Oblast",
        /*     BRY */ "Oblast de Bryansk",
        /*     YAR */ "Yaroslavl Oblast",
        /*     RYA */ "Ryazan Oblast",
        /*     AST */ "Oblast de Astrakhan",
        /*     MOS */ "Oblast de Moscou",
        /*     SMO */ "Smolensk Oblast",
        /*   RU-DA */ "República do Daguestão",
        /*     VOR */ "Voronezh Oblast",
        /*     NGR */ "Oblast de Novgorod",
        /*     PSK */ "Pskov Oblast",
        /*     KOS */ "Kostroma Oblast",
        /*     STA */ "Stavropol Krai",
        /*     KDA */ "Krasnodar Krai",
        /*   RU-KL */ "República da Kalmukia",
        /*     TVE */ "Tver Oblast",
        /*     LEN */ "Oblast de Leningrado",
        /*     ROS */ "Oblast de Rostov",
        /*     VGG */ "Volgograd Oblast",
        /*     VLG */ "Vologda Oblast",
        /*     MUR */ "Murmansk Oblast",
        /*   RU-KR */ "República da Carélia",
        /*     NEN */ "Nenets Autonomous Okrug",
        /*   RU-KO */ "Komi Republic",
        /*     ARK */ "Arkhangelsk Oblast",
        /*   RU-MO */ "República da Mordovia",
        /*     NIZ */ "Nizhny Novgorod Oblast",
        /*     PNZ */ "Penza Oblast",
        /*   RU-KI */ "Kirov Oblast",
        /*   RU-ME */ "Mari El Republic",
        /*     ORE */ "Orenburg Oblast",
        /*     ULY */ "Ulyanovsk Oblast",
        /*   RU-PM */ "Perm Krai",
        /*   RU-BA */ "República da Bashkortostã",
        /*   RU-UD */ "República Udmurt",
        /*   RU-TA */ "República Tatarstan",
        /*     SAM */ "Samara Oblast",
        /*     SAR */ "Saratov Oblast",
        /*     YAN */ "Yamalo-Nenets",
        /*   RU-KM */ "Khanty-Mansi",
        /*     SVE */ "Oblast de Sverdlovsk",
        /*     TYU */ "Tyumen Oblast",
        /*     KGN */ "Oblast de Kurgan",
        /*   RU-CH */ "Chelyabinsk Oblast",
        /*   RU-BU */ "República da Buryatia",
        /*     ZAB */ "Zabaykalsky Krai",
        /*     IRK */ "Oblast de Irkutsk",
        /*     NVS */ "Oblast de Novosibirsk",
        /*     TOM */ "Tomsk Oblast",
        /*     OMS */ "Oblast de Omsk",
        /*   RU-KK */ "República Khakassia",
        /*     KEM */ "Kemerovo Oblast",
        /*   RU-AL */ "República Altai",
        /*     ALT */ "Altai Krai",
        /*   RU-TY */ "Tuva Republic",
        /*     KYA */ "Krasnoyarsk Krai",
        /*     MAG */ "Magadan Oblast",
        /*     CHU */ "Chukotka Okrug",
        /*     KAM */ "Kamchatka Krai",
        /*     SAK */ "Sakhalin Oblast",
        /*   RU-PO */ "Primorsky Krai",
        /*     YEV */ "Oblast autônomo judaico",
        /*     KHA */ "Khabarovsk Krai",
        /*     AMU */ "Oblast de Amur",
        /*   RU-SA */ "República de Sakha|república de Yakutia",
        /*     CAN */ "Canadá",
        /*     RUS */ "Rússia",
        /*   CN-SH */ "Xangai",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Pequim",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Ningxia Hui",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Jiangxi",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "Guangdong",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Nei Mongol|Mongólia Interior",
        /*   CN-HL */ "Heilongjiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Guangxi Zhuang",
        /*   CN-SC */ "Sichuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Xizang|Tibet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Xinjiang Uyghur",
        /*     CHN */ "China",
        /*     UMI */ "Ilhas Menores Distantes dos Estados Unidos",
        /*     CPT */ "Ilha de Clipperton",
        /*     ATA */ "Antártica",
        /*     AAA */ "Internacional|Mundo|Terra"
#else // MAPCODE_SUPPORT_LANGUAGE_PT
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_PT
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_PT_H__
