// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef __INTERNAL_TERRITORY_NAMES_AF_H__
#define __INTERNAL_TERRITORY_NAMES_AF_H__

#ifdef __cplusplus
extern "C" {
#endif

// *** GENERATED FILE (coords.cpp), DO NOT CHANGE OR PRETTIFY ***

static const char *TERRITORY_FULL_NAME_AF[] = {
#ifdef MAPCODE_SUPPORT_LANGUAGE_AF // Afrikaans
        /*     VAT */ "Vatikaanstad|Heilige Stoel",
        /*     MCO */ "Monaco",
        /*     GIB */ "Gibraltar",
        /*     TKL */ "Tokelau",
        /*     CCK */ "Cocos Islands|Keeling Eilande",
        /*     BLM */ "Saint-Barthelemy",
        /*     NRU */ "Nauru",
        /*     TUV */ "Tuvalu",
        /*     MAC */ "Macau",
        /*     SXM */ "Sint Maarten",
        /*     MAF */ "Saint-Martin",
        /*     NFK */ "Norfolk en Philip Island|Philip Island",
        /*     PCN */ "Pitcairn",
        /*     BVT */ "Bouvet Island",
        /*     BMU */ "Bermuda",
        /*     IOT */ "Britse Indiese Oseaan Gebied",
        /*     SMR */ "San Marino",
        /*     GGY */ "Guernsey",
        /*     AIA */ "Anguilla",
        /*     MSR */ "Montserrat",
        /*     JEY */ "Jersey",
        /*     CXR */ "Christmas Island",
        /*     WLF */ "Wallis en Futuna|Futuna",
        /*     VGB */ "Britse Virgin Eilande|Virgin Islands, British",
        /*     LIE */ "Liechtenstein",
        /*     ABW */ "Aruba",
        /*     MHL */ "Marshall-eilande",
        /*     ASM */ "Amerikaanse Samoa|Samoa, Amerikaanse",
        /*     COK */ "Cook eilande",
        /*     SPM */ "Saint-Pierre en Miquelon|Miquelon",
        /*     NIU */ "Niue",
        /*     KNA */ "Saint Kitts en Nevis|Nevis",
        /*     CYM */ "Kaaimanseilande",
        /*     BES */ "Bonaire, St Eustatuis en Saba|Saba|St Eustatius",
        /*     MDV */ "Maldives",
        /*     SHN */ "Saint Helena, Ascension en Tristan da Cunha|Hemelvaart|Tristan da Cunha",
        /*     MLT */ "Malta",
        /*     GRD */ "Grenada",
        /*     VIR */ "Amerikaanse Maagde-eilande|Virgin Islands, US",
        /*     MYT */ "Mayotte",
        /*     SJM */ "Svalbard en Jan Mayen|Jan Mayen",
        /*     VCT */ "St Vincent en die Grenadine|Grenadines",
        /*     HMD */ "Gehoor Island en McDonald Eilande|McDonald Eilande",
        /*     BRB */ "Barbados",
        /*     ATG */ "Antigua en Barbuda|Barbuda",
        /*     CUW */ "Curacao",
        /*     SYC */ "Seychelle",
        /*     PLW */ "Palau",
        /*     MNP */ "Noord Mariana Eilande",
        /*     AND */ "Andorra",
        /*     GUM */ "Guam",
        /*     IMN */ "Eiland Man",
        /*     LCA */ "Saint Lucia",
        /*     FSM */ "Mikronesië|Gefedereerde State van Mikronesië",
        /*     SGP */ "Singapoer",
        /*     TON */ "Tonga",
        /*     DMA */ "Dominica",
        /*     BHR */ "Bahrain",
        /*     KIR */ "Kiribati",
        /*     TCA */ "Turks en Caicos Eilande|Caicos Eilande",
        /*     STP */ "Sao Tomé en Principe|Principe",
        /*     HKG */ "Hong Kong",
        /*     MTQ */ "Martinique",
        /*     FRO */ "Faroëreilande",
        /*     GLP */ "Guadeloupe",
        /*     COM */ "Comore",
        /*     MUS */ "Mauritius",
        /*     REU */ "Reunion",
        /*     LUX */ "Luxemburg",
        /*     WSM */ "Samoa",
        /*     SGS */ "Suid-Georgië en die Suid-Sandwich Eilande|Suid-Sandwich Eilande",
        /*     PYF */ "Frans-Polinesië",
        /*     CPV */ "Kaap Verde",
        /*     TTO */ "Trinidad en Tobago|Tobago",
        /*     BRN */ "Brunei",
        /*     ATF */ "Franse Suidelike en Antarktiese Gebiede",
        /*     PRI */ "Puerto Rico",
        /*     CYP */ "Ciprus",
        /*     LBN */ "Libanon",
        /*     JAM */ "Jamaica",
        /*     GMB */ "Gambië",
        /*     QAT */ "Katar",
        /*     FLK */ "Falkland-eilande",
        /*     VUT */ "Vanuatu",
        /*     MNE */ "Montenegro",
        /*     BHS */ "Bahamas",
        /*     TLS */ "Oos-Timor",
        /*     SWZ */ "Swaziland",
        /*     KWT */ "Kuwait",
        /*     FJI */ "Fidji-eilande",
        /*     NCL */ "New Caledonia",
        /*     SVN */ "Slowenië",
        /*     ISR */ "Israel",
        /*     PSE */ "Palestynse gebiede",
        /*     SLV */ "El Salvador",
        /*     BLZ */ "Belize",
        /*     DJI */ "Djiboeti",
        /*     MKD */ "Macedonië",
        /*     RWA */ "Rwanda",
        /*     HTI */ "Haiti",
        /*     BDI */ "Burundi",
        /*     GNQ */ "Ekwatoriaal-Guinee",
        /*     ALB */ "Albanië",
        /*     SLB */ "Solomon Eilande",
        /*     ARM */ "Armenië",
        /*     LSO */ "Lesotho",
        /*     BEL */ "België",
        /*     MDA */ "Moldawië",
        /*     GNB */ "Guinee-Bissau",
        /*     TWN */ "Taiwan",
        /*     BTN */ "Bhoetan",
        /*     CHE */ "Switserland",
        /*     NLD */ "Nederland",
        /*     DNK */ "Denemarke",
        /*     EST */ "Estland",
        /*     DOM */ "Dominikaanse Republiek",
        /*     SVK */ "Slowakye",
        /*     CRI */ "Costa Rica",
        /*     BIH */ "Bosnië en Herzegovina",
        /*     HRV */ "Kroasië",
        /*     TGO */ "Togo",
        /*     LVA */ "Letland",
        /*     LTU */ "Litaue",
        /*     LKA */ "Sri Lanka",
        /*     GEO */ "Georgia",
        /*     IRL */ "Ierland",
        /*     SLE */ "Sierra Leone",
        /*     PAN */ "Panama",
        /*     CZE */ "Tsjeggiese Republiek",
        /*     GUF */ "Franse Guiana",
        /*     ARE */ "Verenigde Arabiese Emirate",
        /*     AUT */ "Oostenryk",
        /*     AZE */ "Azerbaijan",
        /*     SRB */ "Serwië",
        /*     JOR */ "Jordan",
        /*     PRT */ "Portugal",
        /*     HUN */ "Hongarye",
        /*     KOR */ "Suid-Korea",
        /*     ISL */ "Ysland",
        /*     GTM */ "Guatemala",
        /*     CUB */ "Kuba",
        /*     BGR */ "Bulgarye",
        /*     LBR */ "Liberië",
        /*     HND */ "Honduras",
        /*     BEN */ "Benin",
        /*     ERI */ "Eritrea",
        /*     MWI */ "Malawi",
        /*     PRK */ "Noord-Korea",
        /*     NIC */ "Nicaragua",
        /*     GRC */ "Griekeland",
        /*     TJK */ "Tadjikistan",
        /*     BGD */ "Bangladesj",
        /*     NPL */ "Nepal",
        /*     TUN */ "Tunisië",
        /*     SUR */ "Suriname",
        /*     URY */ "Uruguay",
        /*     KHM */ "Kambodja",
        /*     SYR */ "Sirië",
        /*     SEN */ "Senegal",
        /*     KGZ */ "Kyrgyzstan",
        /*     BLR */ "Wit-Rusland",
        /*     GUY */ "Guyana",
        /*     LAO */ "Laos",
        /*     ROU */ "Roemenië",
        /*     GHA */ "Ghana",
        /*     UGA */ "Uganda",
        /*     GBR */ "Verenigde Koninkryk|Skotland|Groot-Brittanje|Noord-Ierland|Ierland, Noord",
        /*     GIN */ "Guinee",
        /*     ECU */ "Ecuador",
        /*     ESH */ "Wes-Sahara|Sahrawi",
        /*     GAB */ "Gaboen",
        /*     NZL */ "Nieu-Seeland",
        /*     BFA */ "Burkina Faso",
        /*     PHL */ "Filippyne",
        /*     ITA */ "Italië",
        /*     OMN */ "Oman",
        /*     POL */ "Pole",
        /*     CIV */ "Ivoorkus",
        /*     NOR */ "Noorweë",
        /*     MYS */ "Maleisië",
        /*     VNM */ "Viëtnam",
        /*     FIN */ "Finland",
        /*     COG */ "Republiek van die Kongo",
        /*     DEU */ "Duitsland",
        /*     JPN */ "Japan",
        /*     ZWE */ "Zimbabwe",
        /*     PRY */ "Paraguay",
        /*     IRQ */ "Irak",
        /*     MAR */ "Marokko",
        /*     UZB */ "Oesbekistan",
        /*     SWE */ "Swede",
        /*     PNG */ "Papoea-Nieu-Guinee",
        /*     CMR */ "Kameroen",
        /*     TKM */ "Turkmenistan",
        /*     ESP */ "Spanje",
        /*     THA */ "Thailand",
        /*     YEM */ "Jemen",
        /*     FRA */ "Frankryk",
        /*     ALA */ "AAland-eilande",
        /*     KEN */ "Kenia",
        /*     BWA */ "Botswana",
        /*     MDG */ "Madagaskar",
        /*     UKR */ "Oekraïne",
        /*     SSD */ "Suid-Soedan",
        /*     CAF */ "Sentraal-Afrikaanse Republiek",
        /*     SOM */ "Somalië",
        /*     AFG */ "Afghanistan",
        /*     MMR */ "Myanmar|Birma",
        /*     ZMB */ "Zambië",
        /*     CHL */ "Chili",
        /*     TUR */ "Turkye",
        /*     PAK */ "Pakistan",
        /*     MOZ */ "Mosambiek",
        /*     NAM */ "Namibië",
        /*     VEN */ "Venezuela",
        /*     NGA */ "Nigerië",
        /*     TZA */ "Tanzanië",
        /*     EGY */ "Egipte",
        /*     MRT */ "Mauritanië",
        /*     BOL */ "Bolivia",
        /*     ETH */ "Ethiopië",
        /*     COL */ "Colombia",
        /*     ZAF */ "Suid-Afrika",
        /*     MLI */ "Mali",
        /*     AGO */ "Angola",
        /*     NER */ "Niger",
        /*     TCD */ "Chad",
        /*     PER */ "Peru",
        /*     MNG */ "Mongolië",
        /*     IRN */ "Iran",
        /*     LBY */ "Libië",
        /*     SDN */ "Soedan",
        /*     IDN */ "Indonesië",
        /*     DIF */ "Federale Distrik",
        /*     TLA */ "Tlaxcala",
        /*     MOR */ "Morelos",
        /*     AGU */ "Aguascalientes",
        /*   MX-CL */ "Colima",
        /*     QUE */ "Queretaro",
        /*     HID */ "Hidalgo",
        /*   MX-MX */ "Mexiko",
        /*     TAB */ "Tabasco",
        /*     NAY */ "Nayarit",
        /*     GUA */ "Guanajuato",
        /*     PUE */ "Puebla",
        /*     YUC */ "Yucatan",
        /*     ROO */ "Quintana Roo",
        /*     SIN */ "Sinaloa",
        /*     CAM */ "Campeche",
        /*     MIC */ "Michoacan",
        /*     SLP */ "San Luis Potosi",
        /*     GRO */ "Guerrero",
        /*     NLE */ "Nuevo Leon",
        /*     BCN */ "Baja California",
        /*     VER */ "Vera Cruz",
        /*     CHP */ "Chiapas",
        /*     BCS */ "Baja California Sur",
        /*     ZAC */ "Zacatecas",
        /*     JAL */ "Jalisco",
        /*     TAM */ "Tamaulipas",
        /*     OAX */ "Oaxaca",
        /*     DUR */ "Durango",
        /*     COA */ "Coahuila",
        /*     SON */ "Sonora",
        /*     CHH */ "Chihuahua",
        /*     GRL */ "Groenland",
        /*     SAU */ "Saoedi-Arabië",
        /*     COD */ "Kongo-Kinshasa",
        /*     DZA */ "Algerië",
        /*     KAZ */ "Kazakstan",
        /*     ARG */ "Argentinië",
        /*   IN-DD */ "Daman en Diu",
        /*   IN-DN */ "Dadra en Nagar Haveli",
        /*   IN-CH */ "Chandigarh",
        /*   IN-AN */ "Andaman and Nicobar",
        /*   IN-LD */ "Lakshadweep",
        /*   IN-DL */ "Delhi",
        /*   IN-ML */ "Meghalaya",
        /*   IN-NL */ "Nagaland",
        /*   IN-MN */ "Manipur",
        /*   IN-TR */ "Gujarat",
        /*   IN-MZ */ "Mizoram",
        /*   IN-SK */ "Sikkim",
        /*   IN-PB */ "Punjab",
        /*   IN-HR */ "Ladismith",
        /*   IN-AR */ "Arunachal Pradesh",
        /*   IN-AS */ "Assam",
        /*   IN-BR */ "Bihar",
        /*   IN-UT */ "Uttarakhand",
        /*   IN-GA */ "Goa",
        /*   IN-KL */ "Kerala",
        /*   IN-TN */ "Tamil Nadu",
        /*   IN-HP */ "Himachal Pradesh",
        /*   IN-JK */ "Jammu en Kasjmir",
        /*   IN-CT */ "Chhattisgarh",
        /*   IN-JH */ "Jharkhand",
        /*   IN-KA */ "Karnataka",
        /*   IN-RJ */ "Rajasthan",
        /*   IN-OR */ "Odisha|Orissa",
        /*   IN-GJ */ "Gujarat",
        /*   IN-WB */ "Wes-Bengal",
        /*   IN-MP */ "Madhya Pradesh",
        /*   IN-TG */ "Telangana",
        /*   IN-AP */ "Andhra Pradesh",
        /*   IN-MH */ "Maharashtra",
        /*   IN-UP */ "Uttar Pradesh",
        /*   IN-PY */ "Puducherry",
        /*     NSW */ "New South Wales",
        /*     ACT */ "Australian Capital Territory",
        /*     JBT */ "Jervis Bay Territory",
        /*   AU-NT */ "Northern Territory",
        /*   AU-SA */ "Suid-Australië",
        /*     TAS */ "Tasmanië",
        /*     VIC */ "Victoria",
        /*   AU-WA */ "Wes-Australië",
        /*     QLD */ "Queensland",
        /*   BR-DF */ "Distrito Federal",
        /*   BR-SE */ "Sergipe",
        /*   BR-AL */ "Alagoas",
        /*   BR-RJ */ "Rio de Janeiro",
        /*   BR-ES */ "Espirito Santo",
        /*   BR-RN */ "Rio Grande do Norte",
        /*   BR-PB */ "Paraiba",
        /*   BR-SC */ "Santa Catarina",
        /*   BR-PE */ "Pernambuco",
        /*   BR-AP */ "Amapá",
        /*   BR-CE */ "Ceara",
        /*   BR-AC */ "Acre",
        /*   BR-PR */ "Parana",
        /*   BR-RR */ "Roraima",
        /*   BR-RO */ "Rondônia",
        /*   BR-SP */ "Sao Paulo",
        /*   BR-PI */ "Piauí",
        /*   BR-TO */ "Tocantins",
        /*   BR-RS */ "Rio Grande do Sul",
        /*   BR-MA */ "Maranhao",
        /*   BR-GO */ "Goias",
        /*   BR-MS */ "Mato Grosso do Sul",
        /*   BR-BA */ "Bahia",
        /*   BR-MG */ "Minas Gerais",
        /*   BR-MT */ "Mato Grosso",
        /*   BR-PA */ "Para",
        /*   BR-AM */ "Amazonas",
        /*   US-DC */ "Distrik van Columbia",
        /*   US-RI */ "Rhode Island",
        /*   US-DE */ "Delaware",
        /*   US-CT */ "Connecticut",
        /*   US-NJ */ "New Jersey",
        /*   US-NH */ "New Hampshire",
        /*   US-VT */ "Vermont",
        /*   US-MA */ "Massachusetts",
        /*   US-HI */ "Hawaii",
        /*   US-MD */ "Maryland",
        /*   US-WV */ "West Virginia",
        /*   US-SC */ "Suid Carolina",
        /*   US-ME */ "Maine",
        /*   US-IN */ "Indiana",
        /*   US-KY */ "Kentucky",
        /*   US-TN */ "Tennessee",
        /*   US-VA */ "Virginia",
        /*   US-OH */ "Ohio",
        /*   US-PA */ "Pennsylvania",
        /*   US-MS */ "Mississippi",
        /*   US-LA */ "Louisiana",
        /*   US-AL */ "Alabama",
        /*   US-AR */ "Arkansas",
        /*   US-NC */ "Noord-Carolina",
        /*   US-NY */ "New York",
        /*   US-IA */ "Iowa",
        /*   US-IL */ "Illinois",
        /*   US-GA */ "Georgia",
        /*   US-WI */ "Wisconsin",
        /*   US-FL */ "Florida",
        /*   US-MO */ "Missouri",
        /*   US-OK */ "Oklahoma",
        /*   US-ND */ "North Dakota",
        /*   US-WA */ "Washington",
        /*   US-SD */ "South Dakota",
        /*   US-NE */ "Nebraska",
        /*   US-KS */ "Kansas",
        /*   US-ID */ "Idaho",
        /*   US-UT */ "Utah",
        /*   US-MN */ "Minnesota",
        /*   US-MI */ "Michigan",
        /*   US-WY */ "Wyoming",
        /*   US-OR */ "Oregon",
        /*   US-CO */ "Colorado",
        /*   US-NV */ "Nevada",
        /*   US-AZ */ "Arizona",
        /*   US-NM */ "New Mexico",
        /*   US-MT */ "Montana",
        /*   US-CA */ "Kalifornië",
        /*   US-TX */ "Texas",
        /*   US-AK */ "Alaska",
        /*   CA-BC */ "British Columbia",
        /*   CA-AB */ "Alberta",
        /*   CA-ON */ "Ontario",
        /*   CA-QC */ "Quebec",
        /*   CA-SK */ "Saskatchewan",
        /*   CA-MB */ "Manitoba",
        /*   CA-NL */ "Newfoundland",
        /*   CA-NB */ "New Brunswick",
        /*   CA-NS */ "Nova Scotia",
        /*   CA-PE */ "Prince Edward Island",
        /*   CA-YT */ "Yukon",
        /*   CA-NT */ "Northwest Territories",
        /*   CA-NU */ "Nunavut",
        /*     IND */ "Indië",
        /*     AUS */ "Australië",
        /*     BRA */ "Brasilië",
        /*     USA */ "VSA|Verenigde State van Amerika|Amerika",
        /*     MEX */ "Mexiko",
        /*     MOW */ "Moskou",
        /*     SPE */ "Saint Petersburg",
        /*     KGD */ "Kaliningrad Oblast",
        /*   RU-IN */ "Ingoesjetië Republiek",
        /*   RU-AD */ "Adygea Republiek",
        /*   RU-SE */ "Noord-Ossetië-Alania Republiek",
        /*   RU-KB */ "Kabardino-Balkar Republic",
        /*   RU-KC */ "Karachay-Cherkess Republiek",
        /*   RU-CE */ "Tsjetsjeense Republiek",
        /*   RU-CU */ "Chuvash Republiek",
        /*     IVA */ "Ivanovo Oblast",
        /*     LIP */ "Lipetsk Oblast",
        /*     ORL */ "Oryol Oblast",
        /*     TUL */ "Tula Oblast",
        /*   RU-BE */ "Belgorod Oblast",
        /*     VLA */ "Vladimir Oblast",
        /*     KRS */ "Koersk Oblast",
        /*     KLU */ "Kaluga Oblast",
        /*   RU-TT */ "Tambov Oblast",
        /*     BRY */ "Bryansk Oblast",
        /*     YAR */ "Yaroslavl Oblast",
        /*     RYA */ "Ryazan Oblast",
        /*     AST */ "Astrakhan Oblast",
        /*     MOS */ "Moskou Oblast",
        /*     SMO */ "Smolensk Oblast",
        /*   RU-DA */ "Stan Republiek",
        /*     VOR */ "Voronezh Oblast",
        /*     NGR */ "Nowgorod Oblast",
        /*     PSK */ "Pskov Oblast",
        /*     KOS */ "Kostroma Oblast",
        /*     STA */ "Stavropol Krai",
        /*     KDA */ "Krasnodar Krai",
        /*   RU-KL */ "Kalmykia Republiek",
        /*     TVE */ "Tver Oblast",
        /*     LEN */ "Leningrad Oblast",
        /*     ROS */ "Rostov Oblast",
        /*     VGG */ "Volgograd Oblast",
        /*     VLG */ "Vologda Oblast",
        /*     MUR */ "Moermansk Oblast",
        /*   RU-KR */ "Karelië Republiek",
        /*     NEN */ "Nenets outonome Okrug",
        /*   RU-KO */ "Komi Republiek",
        /*     ARK */ "Arkhangelsk Oblast",
        /*   RU-MO */ "Mordovia Republiek",
        /*     NIZ */ "Nizjni Nowgorod Oblast",
        /*     PNZ */ "Penza Oblast",
        /*   RU-KI */ "Kirov Oblast",
        /*   RU-ME */ "Mari El Republiek",
        /*     ORE */ "Orenburg Oblast",
        /*     ULY */ "Ulyanovsk Oblast",
        /*   RU-PM */ "Perm Krai",
        /*   RU-BA */ "Bashkortostan Republiek",
        /*   RU-UD */ "Udmurt Republiek",
        /*   RU-TA */ "Tatarstan Republiek",
        /*     SAM */ "Samara Oblast",
        /*     SAR */ "Saratov Oblast",
        /*     YAN */ "Yamalo-Nenets",
        /*   RU-KM */ "Khanty-Mansi",
        /*     SVE */ "Sverdlovsk Oblast",
        /*     TYU */ "Tyumen Oblast",
        /*     KGN */ "Kurgan Oblast",
        /*   RU-CH */ "Chelyabinsk Oblast",
        /*   RU-BU */ "Buryatia Republiek",
        /*     ZAB */ "Zabaykalsky Krai",
        /*     IRK */ "Irkutsk Oblast",
        /*     NVS */ "Novosibirsk Oblast",
        /*     TOM */ "Tomsk Oblast",
        /*     OMS */ "Omsk Oblast",
        /*   RU-KK */ "Khakassia Republiek",
        /*     KEM */ "Kemerovo Oblast",
        /*   RU-AL */ "Altai Republiek",
        /*     ALT */ "Altai Krai",
        /*   RU-TY */ "Tuva Republiek",
        /*     KYA */ "Krasnoyarsk Krai",
        /*     MAG */ "Magadan Oblast",
        /*     CHU */ "Chukotka Okrug",
        /*     KAM */ "Kamchatka Krai",
        /*     SAK */ "Sakhalin Oblast",
        /*   RU-PO */ "Primorsky Krai",
        /*     YEV */ "Joodse Outonome Oblast",
        /*     KHA */ "Khabarovsk Krai",
        /*     AMU */ "Oostelike Oblast",
        /*   RU-SA */ "Sakha Republiek|Yakutia Republiek",
        /*     CAN */ "Kanada",
        /*     RUS */ "Rusland",
        /*   CN-SH */ "Sjanghai",
        /*   CN-TJ */ "Tianjin",
        /*   CN-BJ */ "Beijing",
        /*   CN-HI */ "Hainan",
        /*   CN-NX */ "Ningxia Hui",
        /*   CN-CQ */ "Chongqing",
        /*   CN-ZJ */ "Zhejiang",
        /*   CN-JS */ "Jiangsu",
        /*   CN-FJ */ "Fujian",
        /*   CN-AH */ "Anhui",
        /*   CN-LN */ "Liaoning",
        /*   CN-SD */ "Shandong",
        /*   CN-SX */ "Shanxi",
        /*   CN-JX */ "Mpumalanga",
        /*   CN-HA */ "Henan",
        /*   CN-GZ */ "Guizhou",
        /*   CN-GD */ "KwaZulu-Natal",
        /*   CN-HB */ "Hubei",
        /*   CN-JL */ "Jilin",
        /*   CN-HE */ "Hebei",
        /*   CN-SN */ "Shaanxi",
        /*   CN-NM */ "Nei Mongol|Inner Mongolia",
        /*   CN-HL */ "Heilunkiang",
        /*   CN-HN */ "Hunan",
        /*   CN-GX */ "Guangxi Zhuang",
        /*   CN-SC */ "Sichuan",
        /*   CN-YN */ "Yunnan",
        /*   CN-XZ */ "Tibet|Tibet",
        /*   CN-GS */ "Gansu",
        /*   CN-QH */ "Qinghai",
        /*   CN-XJ */ "Xinjiang Uyghur",
        /*     CHN */ "Sjina",
        /*     UMI */ "Verenigde State Minor afgeleë eilande",
        /*     CPT */ "Clipperton Island",
        /*     ATA */ "Antarktika",
        /*     AAA */ "International|Wêreldwyd|Aarde"
#else // MAPCODE_SUPPORT_LANGUAGE_AF
        NULL
#endif // MAPCODE_SUPPORT_LANGUAGE_AF
};

#ifdef __cplusplus
}
#endif

#endif // __INTERNAL_TERRITORY_NAMES_AF_H__
